Class: NutanixVmm::CommonV10ConfigFlag
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::CommonV10ConfigFlag
- Defined in:
- lib/nutanix_vmm/models/common_v10_config_flag.rb
Overview
Many entities in the Nutanix APIs carry flags. This object captures all the flags associated with that entity through this object. The field that hosts this type of object must have an attribute called x-bounded-map-keys that tells which flags are actually present for that entity.
Instance Attribute Summary collapse
-
#name ⇒ Object
Name of the flag.
-
#value ⇒ Object
Value of the flag.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommonV10ConfigFlag
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CommonV10ConfigFlag
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::CommonV10ConfigFlag` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::CommonV10ConfigFlag`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = false end end |
Instance Attribute Details
#name ⇒ Object
Name of the flag.
20 21 22 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 20 def name @name end |
#value ⇒ Object
Value of the flag.
23 24 25 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 23 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 26 def self.attribute_map { :'name' => :'name', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 44 def self.openapi_types { :'name' => :'String', :'value' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 129 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && value == o.value end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 144 def hash [name, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end if !@name.nil? && @name.to_s.length < 3 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 105 106 107 |
# File 'lib/nutanix_vmm/models/common_v10_config_flag.rb', line 102 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 128 return false if !@name.nil? && @name.to_s.length < 3 true end |