Class: NutanixVmm::CommonV10ConfigMessage

Inherits:
ApiModelBase show all
Defined in:
lib/nutanix_vmm/models/common_v10_config_message.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CommonV10ConfigMessage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::CommonV10ConfigMessage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::CommonV10ConfigMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'locale')
    self.locale = attributes[:'locale']
  else
    self.locale = 'en_US'
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end
end

Instance Attribute Details

#codeObject

A code that uniquely identifies a message.



19
20
21
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 19

def code
  @code
end

#localeObject

The locale for the message description.



25
26
27
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 25

def locale
  @locale
end

#messageObject

The description of the message.



22
23
24
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 22

def message
  @message
end

#severityObject

Returns the value of attribute severity.



27
28
29
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 27

def severity
  @severity
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 52

def self.attribute_map
  {
    :'code' => :'code',
    :'message' => :'message',
    :'locale' => :'locale',
    :'severity' => :'severity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 163

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 72

def self.openapi_types
  {
    :'code' => :'String',
    :'message' => :'String',
    :'locale' => :'String',
    :'severity' => :'CommonV10ConfigMessageSeverity'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



139
140
141
142
143
144
145
146
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      code == o.code &&
      message == o.message &&
      locale == o.locale &&
      severity == o.severity
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


150
151
152
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 150

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



156
157
158
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 156

def hash
  [code, message, locale, severity].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
# File 'lib/nutanix_vmm/models/common_v10_config_message.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end