Class: NutanixVmm::CommonV10ConfigTenantAwareModel
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::CommonV10ConfigTenantAwareModel
- Defined in:
- lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb
Overview
A model base class whose instances are bound to a specific tenant. This model adds a tenantId to the base model class that it extends and is automatically set by the server.
Instance Attribute Summary collapse
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommonV10ConfigTenantAwareModel
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CommonV10ConfigTenantAwareModel
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 54 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::CommonV10ConfigTenantAwareModel` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::CommonV10ConfigTenantAwareModel`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end end |
Instance Attribute Details
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
20 21 22 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 20 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
30 31 32 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 30 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
35 36 37 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 35 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 23 def self.attribute_map { :'tenant_id' => :'tenantId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 132 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
47 48 49 50 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 47 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 40 def self.openapi_types { :'tenant_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 111 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id end |
#eql?(o) ⇒ Boolean
119 120 121 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 119 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
125 126 127 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 125 def hash [tenant_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 75 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 154 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
88 89 90 91 92 |
# File 'lib/nutanix_vmm/models/common_v10_config_tenant_aware_model.rb', line 88 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) true end |