Class: NutanixVmm::CommonV10ResponseApiLink
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::CommonV10ResponseApiLink
- Defined in:
- lib/nutanix_vmm/models/common_v10_response_api_link.rb
Overview
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
Instance Attribute Summary collapse
-
#href ⇒ Object
The URL at which the entity described by the link can be accessed.
-
#rel ⇒ Object
A name that identifies the relationship of the link to the object that is returned by the URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommonV10ResponseApiLink
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CommonV10ResponseApiLink
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::CommonV10ResponseApiLink` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::CommonV10ResponseApiLink`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'href') self.href = attributes[:'href'] end if attributes.key?(:'rel') self.rel = attributes[:'rel'] end end |
Instance Attribute Details
#href ⇒ Object
The URL at which the entity described by the link can be accessed.
20 21 22 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 20 def href @href end |
#rel ⇒ Object
A name that identifies the relationship of the link to the object that is returned by the URL. The unique value of "self" identifies the URL for the object.
23 24 25 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 23 def rel @rel end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 26 def self.attribute_map { :'href' => :'href', :'rel' => :'rel' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 121 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 44 def self.openapi_types { :'href' => :'String', :'rel' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 99 def ==(o) return true if self.equal?(o) self.class == o.class && href == o.href && rel == o.rel end |
#eql?(o) ⇒ Boolean
108 109 110 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 108 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 114 def hash [href, rel].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
84 85 86 87 88 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 84 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 143 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
92 93 94 95 |
# File 'lib/nutanix_vmm/models/common_v10_response_api_link.rb', line 92 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |