Class: NutanixVmm::DataprotectionV40CommonBaseRecoveryPoint
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::DataprotectionV40CommonBaseRecoveryPoint
- Defined in:
- lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb
Overview
A model that represents common properties of a Recovery point resources
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#creation_time ⇒ Object
The UTC date and time in ISO-8601 format when the Recovery point is created.
-
#expiration_time ⇒ Object
The UTC date and time in ISO-8601 format when the current Recovery point expires and will be garbage collected.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#location_agnostic_id ⇒ Object
Location agnostic identifier of the Recovery point.
-
#name ⇒ Object
The name of the Recovery point.
-
#recovery_point_type ⇒ Object
Returns the value of attribute recovery_point_type.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataprotectionV40CommonBaseRecoveryPoint
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DataprotectionV40CommonBaseRecoveryPoint
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::DataprotectionV40CommonBaseRecoveryPoint` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::DataprotectionV40CommonBaseRecoveryPoint`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'location_agnostic_id') self.location_agnostic_id = attributes[:'location_agnostic_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'creation_time') self.creation_time = attributes[:'creation_time'] end if attributes.key?(:'expiration_time') self.expiration_time = attributes[:'expiration_time'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'recovery_point_type') self.recovery_point_type = attributes[:'recovery_point_type'] end end |
Instance Attribute Details
#creation_time ⇒ Object
The UTC date and time in ISO-8601 format when the Recovery point is created.
35 36 37 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 35 def creation_time @creation_time end |
#expiration_time ⇒ Object
The UTC date and time in ISO-8601 format when the current Recovery point expires and will be garbage collected.
38 39 40 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 38 def expiration_time @expiration_time end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
23 24 25 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 23 def ext_id @ext_id end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
26 27 28 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 26 def links @links end |
#location_agnostic_id ⇒ Object
Location agnostic identifier of the Recovery point.
29 30 31 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 29 def location_agnostic_id @location_agnostic_id end |
#name ⇒ Object
The name of the Recovery point.
32 33 34 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 32 def name @name end |
#recovery_point_type ⇒ Object
Returns the value of attribute recovery_point_type.
42 43 44 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 42 def recovery_point_type @recovery_point_type end |
#status ⇒ Object
Returns the value of attribute status.
40 41 42 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 40 def status @status end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
20 21 22 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 20 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 67 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'location_agnostic_id' => :'locationAgnosticId', :'name' => :'name', :'creation_time' => :'creationTime', :'expiration_time' => :'expirationTime', :'status' => :'status', :'recovery_point_type' => :'recoveryPointType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 327 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
114 115 116 117 118 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 114 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 111 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 107 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 92 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'location_agnostic_id' => :'String', :'name' => :'String', :'creation_time' => :'Time', :'expiration_time' => :'Time', :'status' => :'DataprotectionV40CommonRecoveryPointStatus', :'recovery_point_type' => :'DataprotectionV40CommonRecoveryPointType' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 298 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && location_agnostic_id == o.location_agnostic_id && name == o.name && creation_time == o.creation_time && expiration_time == o.expiration_time && status == o.status && recovery_point_type == o.recovery_point_type end |
#eql?(o) ⇒ Boolean
314 315 316 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 314 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
320 321 322 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 320 def hash [tenant_id, ext_id, links, location_agnostic_id, name, creation_time, expiration_time, status, recovery_point_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 177 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@location_agnostic_id.nil? && @location_agnostic_id !~ pattern invalid_properties.push("invalid value for \"location_agnostic_id\", must conform to the pattern #{pattern}.") end if !@name.nil? && @name.to_s.length > 256 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 349 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/nutanix_vmm/models/dataprotection_v40_common_base_recovery_point.rb', line 212 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@location_agnostic_id.nil? && @location_agnostic_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@name.nil? && @name.to_s.length > 256 true end |