Class: NutanixVmm::VmmV40AhvConfigADSFVmStorageConfig
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvConfigADSFVmStorageConfig
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb
Overview
Storage configuration for VM.
Instance Attribute Summary collapse
-
#is_flash_mode_enabled ⇒ Object
Indicates whether the virtual disk is pinned to the hot tier or not.
-
#qos_config ⇒ Object
Returns the value of attribute qos_config.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvConfigADSFVmStorageConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvConfigADSFVmStorageConfig
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigADSFVmStorageConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigADSFVmStorageConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_flash_mode_enabled') self.is_flash_mode_enabled = attributes[:'is_flash_mode_enabled'] end if attributes.key?(:'qos_config') self.qos_config = attributes[:'qos_config'] end end |
Instance Attribute Details
#is_flash_mode_enabled ⇒ Object
Indicates whether the virtual disk is pinned to the hot tier or not.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 20 def is_flash_mode_enabled @is_flash_mode_enabled end |
#qos_config ⇒ Object
Returns the value of attribute qos_config.
22 23 24 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 22 def qos_config @qos_config end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 25 def self.attribute_map { :'is_flash_mode_enabled' => :'isFlashModeEnabled', :'qos_config' => :'qosConfig' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 120 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 43 def self.openapi_types { :'is_flash_mode_enabled' => :'Boolean', :'qos_config' => :'VmmV40AhvConfigQosConfig' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 98 def ==(o) return true if self.equal?(o) self.class == o.class && is_flash_mode_enabled == o.is_flash_mode_enabled && qos_config == o.qos_config end |
#eql?(o) ⇒ Boolean
107 108 109 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 107 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
113 114 115 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 113 def hash [is_flash_mode_enabled, qos_config].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
83 84 85 86 87 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 83 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 142 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
91 92 93 94 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_adsfvm_storage_config.rb', line 91 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |