Class: NutanixVmm::VmmV40AhvConfigCloudInit

Inherits:
ApiModelBase show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb

Overview

If this field is set, the guest will be customized using cloud-init. Either user_data or custom_key_values should be provided. If custom_key_ves are provided then the user data will be generated using these key-value pairs.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40AhvConfigCloudInit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigCloudInit` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigCloudInit`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'datasource_type')
    self.datasource_type = attributes[:'datasource_type']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'cloud_init_script')
    self.cloud_init_script = attributes[:'cloud_init_script']
  end
end

Instance Attribute Details

#cloud_init_scriptObject

Returns the value of attribute cloud_init_script.



24
25
26
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 24

def cloud_init_script
  @cloud_init_script
end

#datasource_typeObject

Returns the value of attribute datasource_type.



19
20
21
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 19

def datasource_type
  @datasource_type
end

#metadataObject

The contents of the meta_data configuration for cloud-init. This can be formatted as YAML or JSON. The value must be base64 encoded.



22
23
24
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 22

def 
  @metadata
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 49

def self.attribute_map
  {
    :'datasource_type' => :'datasourceType',
    :'metadata' => :'metadata',
    :'cloud_init_script' => :'cloudInitScript'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 170

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 68

def self.openapi_types
  {
    :'datasource_type' => :'VmmV40AhvConfigCloudInitDataSourceType',
    :'metadata' => :'String',
    :'cloud_init_script' => :'VmmV40AhvConfigCloudInitCloudInitScript'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      datasource_type == o.datasource_type &&
       == o. &&
      cloud_init_script == o.cloud_init_script
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 157

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



163
164
165
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 163

def hash
  [datasource_type, , cloud_init_script].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@metadata.nil? && @metadata.to_s.length > 32000
    invalid_properties.push('invalid value for "metadata", the character length must be smaller than or equal to 32000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 192

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
129
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_cloud_init.rb', line 125

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@metadata.nil? && @metadata.to_s.length > 32000
  true
end