Module: NutanixVmm::VmmV40AhvConfigDiskMigrationParamsMigrateDisks
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_config_disk_migration_params_migrate_disks.rb
Overview
Specifies the VmDisks of a VM for migration and the migration plan for them. If all the disks of a VM need to be migrated to the same storage container, only a single migration plan with only the external ID of the destination storage container is needed. If the disks are being migrated to different containers, one plan per disk needs to be specified.
Class Method Summary collapse
-
.build(data) ⇒ Object
Builds the object.
-
.openapi_one_of ⇒ Object
List of class defined in oneOf (OpenAPI v3).
Class Method Details
.build(data) ⇒ Object
Builds the object
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_disk_migration_params_migrate_disks.rb', line 31 def build(data) # Go through the list of oneOf items and attempt to identify the appropriate one. # Note: # - We do not attempt to check whether exactly one item matches. # - No advanced validation of types in some cases (e.g. "x: { type: string }" will happily match { x: 123 }) # due to the way the deserialization is made in the base_object template (it just casts without verifying). # - TODO: scalar values are de facto behaving as if they were nullable. # - TODO: logging when debugging is set. openapi_one_of.each do |klass| begin next if klass == :AnyType # "nullable: true" return find_and_cast_into_type(klass, data) rescue # rescue all errors so we keep iterating even if the current item lookup raises end end openapi_one_of.include?(:AnyType) ? data : nil end |
.openapi_one_of ⇒ Object
List of class defined in oneOf (OpenAPI v3)
21 22 23 24 25 26 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_disk_migration_params_migrate_disks.rb', line 21 def openapi_one_of [ :'VmmV40AhvConfigAllDisksMigrationPlan', :'VmmV40AhvConfigMigrationPlans' ] end |