Class: NutanixVmm::VmmV40AhvConfigGuestTools

Inherits:
ApiModelBase show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb

Overview

The details about Nutanix Guest Tools for a VM.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40AhvConfigGuestTools

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigGuestTools` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigGuestTools`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'is_installed')
    self.is_installed = attributes[:'is_installed']
  end

  if attributes.key?(:'is_enabled')
    self.is_enabled = attributes[:'is_enabled']
  end

  if attributes.key?(:'is_iso_inserted')
    self.is_iso_inserted = attributes[:'is_iso_inserted']
  end

  if attributes.key?(:'capabilities')
    if (value = attributes[:'capabilities']).is_a?(Array)
      self.capabilities = value
    end
  end

  if attributes.key?(:'available_version')
    self.available_version = attributes[:'available_version']
  end

  if attributes.key?(:'guest_os_version')
    self.guest_os_version = attributes[:'guest_os_version']
  end

  if attributes.key?(:'is_reachable')
    self.is_reachable = attributes[:'is_reachable']
  end

  if attributes.key?(:'is_vss_snapshot_capable')
    self.is_vss_snapshot_capable = attributes[:'is_vss_snapshot_capable']
  end

  if attributes.key?(:'is_vm_mobility_drivers_installed')
    self.is_vm_mobility_drivers_installed = attributes[:'is_vm_mobility_drivers_installed']
  end
end

Instance Attribute Details

#available_versionObject

Version of Nutanix Guest Tools available on the cluster.



35
36
37
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 35

def available_version
  @available_version
end

#capabilitiesObject

The list of the application names that are enabled on the guest VM.



32
33
34
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 32

def capabilities
  @capabilities
end

#guest_os_versionObject

Version of the operating system on the VM.



38
39
40
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 38

def guest_os_version
  @guest_os_version
end

#is_enabledObject

Indicates whether Nutanix Guest Tools is enabled or not.



26
27
28
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 26

def is_enabled
  @is_enabled
end

#is_installedObject

Indicates whether Nutanix Guest Tools is installed on the VM or not.



23
24
25
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 23

def is_installed
  @is_installed
end

#is_iso_insertedObject

Indicates whether Nutanix Guest Tools ISO is inserted or not.



29
30
31
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 29

def is_iso_inserted
  @is_iso_inserted
end

#is_reachableObject

Indicates whether the communication from VM to CVM is active or not.



41
42
43
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 41

def is_reachable
  @is_reachable
end

#is_vm_mobility_drivers_installedObject

Indicates whether the VM mobility drivers are installed on the VM or not.



47
48
49
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 47

def is_vm_mobility_drivers_installed
  @is_vm_mobility_drivers_installed
end

#is_vss_snapshot_capableObject

Indicates whether the VM is configured to take VSS snapshots through NGT or not.



44
45
46
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 44

def is_vss_snapshot_capable
  @is_vss_snapshot_capable
end

#versionObject

Version of Nutanix Guest Tools installed on the VM.



20
21
22
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 20

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 50

def self.attribute_map
  {
    :'version' => :'version',
    :'is_installed' => :'isInstalled',
    :'is_enabled' => :'isEnabled',
    :'is_iso_inserted' => :'isIsoInserted',
    :'capabilities' => :'capabilities',
    :'available_version' => :'availableVersion',
    :'guest_os_version' => :'guestOsVersion',
    :'is_reachable' => :'isReachable',
    :'is_vss_snapshot_capable' => :'isVssSnapshotCapable',
    :'is_vm_mobility_drivers_installed' => :'isVmMobilityDriversInstalled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 76

def self.openapi_types
  {
    :'version' => :'String',
    :'is_installed' => :'Boolean',
    :'is_enabled' => :'Boolean',
    :'is_iso_inserted' => :'Boolean',
    :'capabilities' => :'Array<VmmV40AhvConfigNgtCapability>',
    :'available_version' => :'String',
    :'guest_os_version' => :'String',
    :'is_reachable' => :'Boolean',
    :'is_vss_snapshot_capable' => :'Boolean',
    :'is_vm_mobility_drivers_installed' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version == o.version &&
      is_installed == o.is_installed &&
      is_enabled == o.is_enabled &&
      is_iso_inserted == o.is_iso_inserted &&
      capabilities == o.capabilities &&
      available_version == o.available_version &&
      guest_os_version == o.guest_os_version &&
      is_reachable == o.is_reachable &&
      is_vss_snapshot_capable == o.is_vss_snapshot_capable &&
      is_vm_mobility_drivers_installed == o.is_vm_mobility_drivers_installed
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 224

def hash
  [version, is_installed, is_enabled, is_iso_inserted, capabilities, available_version, guest_os_version, is_reachable, is_vss_snapshot_capable, is_vm_mobility_drivers_installed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@capabilities.nil? && @capabilities.length > 2
    invalid_properties.push('invalid value for "capabilities", number of items must be less than or equal to 2.')
  end

  if !@capabilities.nil? && @capabilities.length < 0
    invalid_properties.push('invalid value for "capabilities", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@capabilities.nil? && @capabilities.length > 2
  return false if !@capabilities.nil? && @capabilities.length < 0
  true
end