Class: NutanixVmm::VmmV40AhvConfigGuestToolsInstallConfig

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb

Overview

Arguments for installing Nutanix Guest Tools.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40AhvConfigGuestToolsInstallConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigGuestToolsInstallConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigGuestToolsInstallConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'capabilities')
    if (value = attributes[:'capabilities']).is_a?(Array)
      self.capabilities = value
    end
  end

  if attributes.key?(:'credential')
    self.credential = attributes[:'credential']
  end

  if attributes.key?(:'reboot_preference')
    self.reboot_preference = attributes[:'reboot_preference']
  end
end

Instance Attribute Details

#capabilitiesObject

The list of the application names that are enabled on the guest VM.



20
21
22
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 20

def capabilities
  @capabilities
end

#credentialObject

Returns the value of attribute credential.



22
23
24
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 22

def credential
  @credential
end

#reboot_preferenceObject

Returns the value of attribute reboot_preference.



24
25
26
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 24

def reboot_preference
  @reboot_preference
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



36
37
38
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 36

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 41

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 27

def self.attribute_map
  {
    :'capabilities' => :'capabilities',
    :'credential' => :'credential',
    :'reboot_preference' => :'rebootPreference'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 159

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



55
56
57
58
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 46

def self.openapi_types
  {
    :'capabilities' => :'Array<VmmV40AhvConfigNgtCapability>',
    :'credential' => :'VmmV40AhvConfigCredential',
    :'reboot_preference' => :'VmmV40AhvConfigRebootPreference'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



136
137
138
139
140
141
142
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 136

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      capabilities == o.capabilities &&
      credential == o.credential &&
      reboot_preference == o.reboot_preference
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


146
147
148
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 146

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



152
153
154
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 152

def hash
  [capabilities, credential, reboot_preference].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 93

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@capabilities.nil? && @capabilities.length > 2
    invalid_properties.push('invalid value for "capabilities", number of items must be less than or equal to 2.')
  end

  if !@capabilities.nil? && @capabilities.length < 0
    invalid_properties.push('invalid value for "capabilities", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 181

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



109
110
111
112
113
114
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_guest_tools_install_config.rb', line 109

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@capabilities.nil? && @capabilities.length > 2
  return false if !@capabilities.nil? && @capabilities.length < 0
  true
end