Class: NutanixVmm::VmmV40AhvConfigIpv4Config

Inherits:
ApiModelBase show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb

Overview

The IP address configurations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40AhvConfigIpv4Config

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigIpv4Config` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigIpv4Config`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'should_assign_ip')
    self.should_assign_ip = attributes[:'should_assign_ip']
  end

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'secondary_ip_address_list')
    if (value = attributes[:'secondary_ip_address_list']).is_a?(Array)
      self.secondary_ip_address_list = value
    end
  end
end

Instance Attribute Details

#ip_addressObject

Returns the value of attribute ip_address.



22
23
24
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 22

def ip_address
  @ip_address
end

#secondary_ip_address_listObject

Secondary IP addresses for the NIC.



25
26
27
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 25

def secondary_ip_address_list
  @secondary_ip_address_list
end

#should_assign_ipObject

If set to true (default value), an IP address must be assigned to the VM NIC - either the one explicitly specified by the user or allocated automatically by the IPAM service by not specifying the IP address. If false, then no IP assignment is required for this VM NIC.



20
21
22
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 20

def should_assign_ip
  @should_assign_ip
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 28

def self.attribute_map
  {
    :'should_assign_ip' => :'shouldAssignIp',
    :'ip_address' => :'ipAddress',
    :'secondary_ip_address_list' => :'secondaryIpAddressList'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 47

def self.openapi_types
  {
    :'should_assign_ip' => :'Boolean',
    :'ip_address' => :'CommonV10ConfigIPv4Address',
    :'secondary_ip_address_list' => :'Array<CommonV10ConfigIPv4Address>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



137
138
139
140
141
142
143
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 137

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      should_assign_ip == o.should_assign_ip &&
      ip_address == o.ip_address &&
      secondary_ip_address_list == o.secondary_ip_address_list
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 147

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



153
154
155
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 153

def hash
  [should_assign_ip, ip_address, secondary_ip_address_list].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 94

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@secondary_ip_address_list.nil? && @secondary_ip_address_list.length > 100
    invalid_properties.push('invalid value for "secondary_ip_address_list", number of items must be less than or equal to 100.')
  end

  if !@secondary_ip_address_list.nil? && @secondary_ip_address_list.length < 0
    invalid_properties.push('invalid value for "secondary_ip_address_list", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



110
111
112
113
114
115
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_ipv4_config.rb', line 110

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@secondary_ip_address_list.nil? && @secondary_ip_address_list.length > 100
  return false if !@secondary_ip_address_list.nil? && @secondary_ip_address_list.length < 0
  true
end