Class: NutanixVmm::VmmV40AhvConfigSysprep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvConfigSysprep
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb
Overview
If this field is set, the guest will be customized using Sysprep. Either unattend_xml or custom_key_values should be provided. If custom_key_values are provided then the unattended answer file will be generated using these key-value pairs.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#install_type ⇒ Object
Returns the value of attribute install_type.
-
#sysprep_script ⇒ Object
Returns the value of attribute sysprep_script.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvConfigSysprep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvConfigSysprep
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigSysprep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigSysprep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'install_type') self.install_type = attributes[:'install_type'] end if attributes.key?(:'sysprep_script') self.sysprep_script = attributes[:'sysprep_script'] end end |
Instance Attribute Details
#install_type ⇒ Object
Returns the value of attribute install_type.
19 20 21 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 19 def install_type @install_type end |
#sysprep_script ⇒ Object
Returns the value of attribute sysprep_script.
21 22 23 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 21 def sysprep_script @sysprep_script end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 46 def self.attribute_map { :'install_type' => :'installType', :'sysprep_script' => :'sysprepScript' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 141 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 64 def self.openapi_types { :'install_type' => :'VmmV40AhvConfigInstallType', :'sysprep_script' => :'VmmV40AhvConfigSysprepSysprepScript' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 119 def ==(o) return true if self.equal?(o) self.class == o.class && install_type == o.install_type && sysprep_script == o.sysprep_script end |
#eql?(o) ⇒ Boolean
128 129 130 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 128 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 134 def hash [install_type, sysprep_script].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 108 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 104 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_sysprep.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |