Class: NutanixVmm::VmmV40AhvConfigVmAllOfBootConfig

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb

Overview

Indicates the order of device types in which the VM should try to boot from. If the boot device order is not provided the system will decide an appropriate boot device order.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40AhvConfigVmAllOfBootConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 53

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigVmAllOfBootConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigVmAllOfBootConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'object_type')
    self.object_type = attributes[:'object_type']
  else
    self.object_type = nil
  end
end

Instance Attribute Details

#object_typeObject

Returns the value of attribute object_type.



19
20
21
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 19

def object_type
  @object_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



29
30
31
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 29

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



34
35
36
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 34

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



22
23
24
25
26
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 22

def self.attribute_map
  {
    :'object_type' => :'$objectType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 127

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



46
47
48
49
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 46

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



39
40
41
42
43
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 39

def self.openapi_types
  {
    :'object_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



106
107
108
109
110
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 106

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      object_type == o.object_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


114
115
116
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 114

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



120
121
122
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 120

def hash
  [object_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



76
77
78
79
80
81
82
83
84
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 76

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @object_type.nil?
    invalid_properties.push('invalid value for "object_type", object_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 149

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



88
89
90
91
92
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_all_of_boot_config.rb', line 88

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @object_type.nil?
  true
end