Class: NutanixVmm::VmmV40AhvConfigVmDiskReference
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvConfigVmDiskReference
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb
Overview
Reference to an existing VM disk.
Instance Attribute Summary collapse
-
#disk_address ⇒ Object
Returns the value of attribute disk_address.
-
#disk_ext_id ⇒ Object
A globally unique identifier of a VM disk of type UUID.
-
#vm_reference ⇒ Object
Returns the value of attribute vm_reference.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvConfigVmDiskReference
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvConfigVmDiskReference
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigVmDiskReference` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigVmDiskReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'disk_ext_id') self.disk_ext_id = attributes[:'disk_ext_id'] end if attributes.key?(:'disk_address') self.disk_address = attributes[:'disk_address'] end if attributes.key?(:'vm_reference') self.vm_reference = attributes[:'vm_reference'] end end |
Instance Attribute Details
#disk_address ⇒ Object
Returns the value of attribute disk_address.
22 23 24 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 22 def disk_address @disk_address end |
#disk_ext_id ⇒ Object
A globally unique identifier of a VM disk of type UUID.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 20 def disk_ext_id @disk_ext_id end |
#vm_reference ⇒ Object
Returns the value of attribute vm_reference.
24 25 26 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 24 def vm_reference @vm_reference end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 27 def self.attribute_map { :'disk_ext_id' => :'diskExtId', :'disk_address' => :'diskAddress', :'vm_reference' => :'vmReference' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 150 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 46 def self.openapi_types { :'disk_ext_id' => :'String', :'disk_address' => :'VmmV40AhvConfigDiskAddress', :'vm_reference' => :'VmmV40AhvConfigVmReference' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 127 def ==(o) return true if self.equal?(o) self.class == o.class && disk_ext_id == o.disk_ext_id && disk_address == o.disk_address && vm_reference == o.vm_reference end |
#eql?(o) ⇒ Boolean
137 138 139 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 137 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 143 def hash [disk_ext_id, disk_address, vm_reference].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
91 92 93 94 95 96 97 98 99 100 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 91 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@disk_ext_id.nil? && @disk_ext_id !~ pattern invalid_properties.push("invalid value for \"disk_ext_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
104 105 106 107 108 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk_reference.rb', line 104 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@disk_ext_id.nil? && @disk_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) true end |