Class: NutanixVmm::VmmV40AhvPoliciesLegacyVmAntiAffinityPolicy

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb

Overview

Legacy VM-VM Anti-Affinity policy configuration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40AhvPoliciesLegacyVmAntiAffinityPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvPoliciesLegacyVmAntiAffinityPolicy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvPoliciesLegacyVmAntiAffinityPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'ext_id')
    self.ext_id = attributes[:'ext_id']
  end

  if attributes.key?(:'links')
    if (value = attributes[:'links']).is_a?(Array)
      self.links = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'cluster')
    self.cluster = attributes[:'cluster']
  end

  if attributes.key?(:'vms')
    if (value = attributes[:'vms']).is_a?(Array)
      self.vms = value
    end
  end
end

Instance Attribute Details

#clusterObject

Returns the value of attribute cluster.



31
32
33
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 31

def cluster
  @cluster
end

#ext_idObject

A globally unique identifier of an instance that is suitable for external consumption.



23
24
25
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 23

def ext_id
  @ext_id
end

A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.



26
27
28
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 26

def links
  @links
end

#nameObject

VM Anti-Affinity policy name corresponding to a legacy VM-VM Anti-Affinity policy.



29
30
31
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 29

def name
  @name
end

#tenant_idObject

A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).



20
21
22
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 20

def tenant_id
  @tenant_id
end

#vmsObject

VMs that are part of the legacy VM-VM Anti-Affinity policy.



34
35
36
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 34

def vms
  @vms
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 37

def self.attribute_map
  {
    :'tenant_id' => :'tenantId',
    :'ext_id' => :'extId',
    :'links' => :'links',
    :'name' => :'name',
    :'cluster' => :'cluster',
    :'vms' => :'vms'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 294

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



78
79
80
81
82
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 78

def self.openapi_all_of
  [
  :'CommonV10ResponseExternalizableAbstractModel'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
75
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 71

def self.openapi_nullable
  Set.new([
    :'ext_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 59

def self.openapi_types
  {
    :'tenant_id' => :'String',
    :'ext_id' => :'String',
    :'links' => :'Array<CommonV10ResponseApiLink>',
    :'name' => :'String',
    :'cluster' => :'VmmV40AhvPoliciesClusterReference',
    :'vms' => :'Array<VmmV40AhvPoliciesVmReference>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



268
269
270
271
272
273
274
275
276
277
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 268

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tenant_id == o.tenant_id &&
      ext_id == o.ext_id &&
      links == o.links &&
      name == o.name &&
      cluster == o.cluster &&
      vms == o.vms
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


281
282
283
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 281

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



287
288
289
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 287

def hash
  [tenant_id, ext_id, links, name, cluster, vms].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@tenant_id.nil? && @tenant_id !~ pattern
    invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@ext_id.nil? && @ext_id !~ pattern
    invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.")
  end

  if !@links.nil? && @links.length > 20
    invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.')
  end

  if !@links.nil? && @links.length < 0
    invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.')
  end

  if !@name.nil? && @name.to_s.length > 512
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 512.')
  end

  if !@name.nil? && @name.to_s.length < 0
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 0.')
  end

  if !@vms.nil? && @vms.length > 4096
    invalid_properties.push('invalid value for "vms", number of items must be less than or equal to 4096.')
  end

  if !@vms.nil? && @vms.length < 0
    invalid_properties.push('invalid value for "vms", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 316

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_legacy_vm_anti_affinity_policy.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@links.nil? && @links.length > 20
  return false if !@links.nil? && @links.length < 0
  return false if !@name.nil? && @name.to_s.length > 512
  return false if !@name.nil? && @name.to_s.length < 0
  return false if !@vms.nil? && @vms.length > 4096
  return false if !@vms.nil? && @vms.length < 0
  true
end