Class: NutanixVmm::VmmV40ContentCompleteGuestUpdateSpec

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb

Overview

Input to template complete guest OS update.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40ContentCompleteGuestUpdateSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ContentCompleteGuestUpdateSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ContentCompleteGuestUpdateSpec`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version_name')
    self.version_name = attributes[:'version_name']
  else
    self.version_name = nil
  end

  if attributes.key?(:'version_description')
    self.version_description = attributes[:'version_description']
  else
    self.version_description = nil
  end

  if attributes.key?(:'is_active_version')
    self.is_active_version = attributes[:'is_active_version']
  else
    self.is_active_version = true
  end
end

Instance Attribute Details

#is_active_versionObject

Specify whether to mark the template version as active or not. The newly created version during template creation, update, or guest OS update is set to active by default unless specified otherwise.



26
27
28
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 26

def is_active_version
  @is_active_version
end

#version_descriptionObject

The user-defined description of a template version.



23
24
25
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 23

def version_description
  @version_description
end

#version_nameObject

The user-defined name of a template version.



20
21
22
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 20

def version_name
  @version_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 29

def self.attribute_map
  {
    :'version_name' => :'versionName',
    :'version_description' => :'versionDescription',
    :'is_active_version' => :'isActiveVersion'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 185

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 48

def self.openapi_types
  {
    :'version_name' => :'String',
    :'version_description' => :'String',
    :'is_active_version' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version_name == o.version_name &&
      version_description == o.version_description &&
      is_active_version == o.is_active_version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


172
173
174
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 172

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



178
179
180
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 178

def hash
  [version_name, version_description, is_active_version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 99

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @version_name.nil?
    invalid_properties.push('invalid value for "version_name", version_name cannot be nil.')
  end

  if @version_name.to_s.length > 256
    invalid_properties.push('invalid value for "version_name", the character length must be smaller than or equal to 256.')
  end

  if @version_description.nil?
    invalid_properties.push('invalid value for "version_description", version_description cannot be nil.')
  end

  if @version_description.to_s.length > 1000
    invalid_properties.push('invalid value for "version_description", the character length must be smaller than or equal to 1000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 207

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
128
129
130
# File 'lib/nutanix_vmm/models/vmm_v40_content_complete_guest_update_spec.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @version_name.nil?
  return false if @version_name.to_s.length > 256
  return false if @version_description.nil?
  return false if @version_description.to_s.length > 1000
  true
end