Class: NutanixVmm::VmmV40ContentImage

Inherits:
ApiModelBase show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_content_image.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40ContentImage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 150

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ContentImage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ContentImage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'ext_id')
    self.ext_id = attributes[:'ext_id']
  end

  if attributes.key?(:'links')
    if (value = attributes[:'links']).is_a?(Array)
      self.links = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'checksum')
    self.checksum = attributes[:'checksum']
  end

  if attributes.key?(:'size_bytes')
    self.size_bytes = attributes[:'size_bytes']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'category_ext_ids')
    if (value = attributes[:'category_ext_ids']).is_a?(Array)
      self.category_ext_ids = value
    end
  end

  if attributes.key?(:'cluster_location_ext_ids')
    if (value = attributes[:'cluster_location_ext_ids']).is_a?(Array)
      self.cluster_location_ext_ids = value
    end
  end

  if attributes.key?(:'create_time')
    self.create_time = attributes[:'create_time']
  end

  if attributes.key?(:'last_update_time')
    self.last_update_time = attributes[:'last_update_time']
  end

  if attributes.key?(:'owner_ext_id')
    self.owner_ext_id = attributes[:'owner_ext_id']
  end

  if attributes.key?(:'placement_policy_status')
    if (value = attributes[:'placement_policy_status']).is_a?(Array)
      self.placement_policy_status = value
    end
  end
end

Instance Attribute Details

#category_ext_idsObject

List of external identifier of the category for an image.



43
44
45
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 43

def category_ext_ids
  @category_ext_ids
end

#checksumObject

Returns the value of attribute checksum.



35
36
37
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 35

def checksum
  @checksum
end

#cluster_location_ext_idsObject

List of external identifier of the cluster where the image is located.



46
47
48
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 46

def cluster_location_ext_ids
  @cluster_location_ext_ids
end

#create_timeObject

Image creation time.



49
50
51
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 49

def create_time
  @create_time
end

#descriptionObject

The user-defined description of an image.



31
32
33
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 31

def description
  @description
end

#ext_idObject

A globally unique identifier of an instance that is suitable for external consumption.



22
23
24
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 22

def ext_id
  @ext_id
end

#last_update_timeObject

Last updated time of an image.



52
53
54
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 52

def last_update_time
  @last_update_time
end

A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.



25
26
27
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 25

def links
  @links
end

#nameObject

The user-defined name of an image.



28
29
30
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 28

def name
  @name
end

#owner_ext_idObject

External identifier of the owner of the image.



55
56
57
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 55

def owner_ext_id
  @owner_ext_id
end

#placement_policy_statusObject

Status of an image placement policy.



58
59
60
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 58

def placement_policy_status
  @placement_policy_status
end

#size_bytesObject

The size of an image in bytes.



38
39
40
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 38

def size_bytes
  @size_bytes
end

#sourceObject

Returns the value of attribute source.



40
41
42
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 40

def source
  @source
end

#tenant_idObject

A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).



19
20
21
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 19

def tenant_id
  @tenant_id
end

#typeObject

Returns the value of attribute type.



33
34
35
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 33

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



104
105
106
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 104

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 109

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 83

def self.attribute_map
  {
    :'tenant_id' => :'tenantId',
    :'ext_id' => :'extId',
    :'links' => :'links',
    :'name' => :'name',
    :'description' => :'description',
    :'type' => :'type',
    :'checksum' => :'checksum',
    :'size_bytes' => :'sizeBytes',
    :'source' => :'source',
    :'category_ext_ids' => :'categoryExtIds',
    :'cluster_location_ext_ids' => :'clusterLocationExtIds',
    :'create_time' => :'createTime',
    :'last_update_time' => :'lastUpdateTime',
    :'owner_ext_id' => :'ownerExtId',
    :'placement_policy_status' => :'placementPolicyStatus'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 527

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



142
143
144
145
146
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 142

def self.openapi_all_of
  [
  :'CommonV10ResponseExternalizableAbstractModel'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



135
136
137
138
139
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 135

def self.openapi_nullable
  Set.new([
    :'ext_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 114

def self.openapi_types
  {
    :'tenant_id' => :'String',
    :'ext_id' => :'String',
    :'links' => :'Array<CommonV10ResponseApiLink>',
    :'name' => :'String',
    :'description' => :'String',
    :'type' => :'VmmV40ContentImageType',
    :'checksum' => :'VirtualDiskImageChecksum',
    :'size_bytes' => :'Integer',
    :'source' => :'VirtualDiskImageSource',
    :'category_ext_ids' => :'Array<String>',
    :'cluster_location_ext_ids' => :'Array<String>',
    :'create_time' => :'Time',
    :'last_update_time' => :'Time',
    :'owner_ext_id' => :'String',
    :'placement_policy_status' => :'Array<VmmV40ContentImagePlacementStatus>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 492

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tenant_id == o.tenant_id &&
      ext_id == o.ext_id &&
      links == o.links &&
      name == o.name &&
      description == o.description &&
      type == o.type &&
      checksum == o.checksum &&
      size_bytes == o.size_bytes &&
      source == o.source &&
      category_ext_ids == o.category_ext_ids &&
      cluster_location_ext_ids == o.cluster_location_ext_ids &&
      create_time == o.create_time &&
      last_update_time == o.last_update_time &&
      owner_ext_id == o.owner_ext_id &&
      placement_policy_status == o.placement_policy_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


514
515
516
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 514

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



520
521
522
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 520

def hash
  [tenant_id, ext_id, links, name, description, type, checksum, size_bytes, source, category_ext_ids, cluster_location_ext_ids, create_time, last_update_time, owner_ext_id, placement_policy_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 239

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@tenant_id.nil? && @tenant_id !~ pattern
    invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@ext_id.nil? && @ext_id !~ pattern
    invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.")
  end

  if !@links.nil? && @links.length > 20
    invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.')
  end

  if !@links.nil? && @links.length < 0
    invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 256
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length > 1000
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@category_ext_ids.nil? && @category_ext_ids.length > 1250
    invalid_properties.push('invalid value for "category_ext_ids", number of items must be less than or equal to 1250.')
  end

  if !@category_ext_ids.nil? && @category_ext_ids.length < 0
    invalid_properties.push('invalid value for "category_ext_ids", number of items must be greater than or equal to 0.')
  end

  if !@cluster_location_ext_ids.nil? && @cluster_location_ext_ids.length > 200
    invalid_properties.push('invalid value for "cluster_location_ext_ids", number of items must be less than or equal to 200.')
  end

  if !@cluster_location_ext_ids.nil? && @cluster_location_ext_ids.length < 0
    invalid_properties.push('invalid value for "cluster_location_ext_ids", number of items must be greater than or equal to 0.')
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@owner_ext_id.nil? && @owner_ext_id !~ pattern
    invalid_properties.push("invalid value for \"owner_ext_id\", must conform to the pattern #{pattern}.")
  end

  if !@placement_policy_status.nil? && @placement_policy_status.length > 100
    invalid_properties.push('invalid value for "placement_policy_status", number of items must be less than or equal to 100.')
  end

  if !@placement_policy_status.nil? && @placement_policy_status.length < 0
    invalid_properties.push('invalid value for "placement_policy_status", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



549
550
551
552
553
554
555
556
557
558
559
560
561
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 549

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/nutanix_vmm/models/vmm_v40_content_image.rb', line 314

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@links.nil? && @links.length > 20
  return false if !@links.nil? && @links.length < 0
  return false if @name.nil?
  return false if @name.to_s.length > 256
  return false if @name.to_s.length < 1
  return false if !@description.nil? && @description.to_s.length > 1000
  return false if @type.nil?
  return false if !@category_ext_ids.nil? && @category_ext_ids.length > 1250
  return false if !@category_ext_ids.nil? && @category_ext_ids.length < 0
  return false if !@cluster_location_ext_ids.nil? && @cluster_location_ext_ids.length > 200
  return false if !@cluster_location_ext_ids.nil? && @cluster_location_ext_ids.length < 0
  return false if !@owner_ext_id.nil? && @owner_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@placement_policy_status.nil? && @placement_policy_status.length > 100
  return false if !@placement_policy_status.nil? && @placement_policy_status.length < 0
  true
end