Class: NutanixVmm::VmmV40ContentTemplate

Inherits:
ApiModelBase show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_content_template.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40ContentTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ContentTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ContentTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'ext_id')
    self.ext_id = attributes[:'ext_id']
  end

  if attributes.key?(:'links')
    if (value = attributes[:'links']).is_a?(Array)
      self.links = value
    end
  end

  if attributes.key?(:'template_name')
    self.template_name = attributes[:'template_name']
  end

  if attributes.key?(:'template_description')
    self.template_description = attributes[:'template_description']
  end

  if attributes.key?(:'template_version_spec')
    self.template_version_spec = attributes[:'template_version_spec']
  end

  if attributes.key?(:'guest_update_status')
    self.guest_update_status = attributes[:'guest_update_status']
  end

  if attributes.key?(:'create_time')
    self.create_time = attributes[:'create_time']
  end

  if attributes.key?(:'update_time')
    self.update_time = attributes[:'update_time']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end
end

Instance Attribute Details

#create_timeObject

Time when the template was created.



38
39
40
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 38

def create_time
  @create_time
end

#created_byObject

Returns the value of attribute created_by.



43
44
45
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 43

def created_by
  @created_by
end

#ext_idObject

A globally unique identifier of an instance that is suitable for external consumption.



22
23
24
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 22

def ext_id
  @ext_id
end

#guest_update_statusObject

Returns the value of attribute guest_update_status.



35
36
37
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 35

def guest_update_status
  @guest_update_status
end

A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.



25
26
27
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 25

def links
  @links
end

#template_descriptionObject

The user-defined description of a template.



31
32
33
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 31

def template_description
  @template_description
end

#template_nameObject

The user-defined name of a template.



28
29
30
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 28

def template_name
  @template_name
end

#template_version_specObject

Returns the value of attribute template_version_spec.



33
34
35
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 33

def template_version_spec
  @template_version_spec
end

#tenant_idObject

A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).



19
20
21
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 19

def tenant_id
  @tenant_id
end

#update_timeObject

Time when the template was last updated.



41
42
43
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 41

def update_time
  @update_time
end

#updated_byObject

Returns the value of attribute updated_by.



45
46
47
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 45

def updated_by
  @updated_by
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 48

def self.attribute_map
  {
    :'tenant_id' => :'tenantId',
    :'ext_id' => :'extId',
    :'links' => :'links',
    :'template_name' => :'templateName',
    :'template_description' => :'templateDescription',
    :'template_version_spec' => :'templateVersionSpec',
    :'guest_update_status' => :'guestUpdateStatus',
    :'create_time' => :'createTime',
    :'update_time' => :'updateTime',
    :'created_by' => :'createdBy',
    :'updated_by' => :'updatedBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 329

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



99
100
101
102
103
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 99

def self.openapi_all_of
  [
  :'CommonV10ResponseExternalizableAbstractModel'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 92

def self.openapi_nullable
  Set.new([
    :'ext_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 75

def self.openapi_types
  {
    :'tenant_id' => :'String',
    :'ext_id' => :'String',
    :'links' => :'Array<CommonV10ResponseApiLink>',
    :'template_name' => :'String',
    :'template_description' => :'String',
    :'template_version_spec' => :'VmmV40ContentTemplateVersionSpec',
    :'guest_update_status' => :'VmmV40ContentGuestUpdateStatus',
    :'create_time' => :'Time',
    :'update_time' => :'Time',
    :'created_by' => :'VmmV40ContentTemplateUser',
    :'updated_by' => :'VmmV40ContentTemplateUser'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tenant_id == o.tenant_id &&
      ext_id == o.ext_id &&
      links == o.links &&
      template_name == o.template_name &&
      template_description == o.template_description &&
      template_version_spec == o.template_version_spec &&
      guest_update_status == o.guest_update_status &&
      create_time == o.create_time &&
      update_time == o.update_time &&
      created_by == o.created_by &&
      updated_by == o.updated_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


316
317
318
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 316

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



322
323
324
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 322

def hash
  [tenant_id, ext_id, links, template_name, template_description, template_version_spec, guest_update_status, create_time, update_time, created_by, updated_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 170

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@tenant_id.nil? && @tenant_id !~ pattern
    invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@ext_id.nil? && @ext_id !~ pattern
    invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.")
  end

  if !@links.nil? && @links.length > 20
    invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.')
  end

  if !@links.nil? && @links.length < 0
    invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.')
  end

  if !@template_name.nil? && @template_name.to_s.length > 256
    invalid_properties.push('invalid value for "template_name", the character length must be smaller than or equal to 256.')
  end

  if !@template_name.nil? && @template_name.to_s.length < 1
    invalid_properties.push('invalid value for "template_name", the character length must be greater than or equal to 1.')
  end

  if !@template_description.nil? && @template_description.to_s.length > 1000
    invalid_properties.push('invalid value for "template_description", the character length must be smaller than or equal to 1000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
217
218
# File 'lib/nutanix_vmm/models/vmm_v40_content_template.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@links.nil? && @links.length > 20
  return false if !@links.nil? && @links.length < 0
  return false if !@template_name.nil? && @template_name.to_s.length > 256
  return false if !@template_name.nil? && @template_name.to_s.length < 1
  return false if !@template_description.nil? && @template_description.to_s.length > 1000
  true
end