Class: NutanixVmm::VmmV40ContentTemplateDeployment

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb

Overview

The template deployment model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40ContentTemplateDeployment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ContentTemplateDeployment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ContentTemplateDeployment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version_id')
    self.version_id = attributes[:'version_id']
  end

  if attributes.key?(:'number_of_vms')
    self.number_of_vms = attributes[:'number_of_vms']
  else
    self.number_of_vms = 1
  end

  if attributes.key?(:'override_vm_config_map')
    if (value = attributes[:'override_vm_config_map']).is_a?(Hash)
      self.override_vm_config_map = value
    end
  end

  if attributes.key?(:'cluster_reference')
    self.cluster_reference = attributes[:'cluster_reference']
  else
    self.cluster_reference = nil
  end
end

Instance Attribute Details

#cluster_referenceObject

The identifier of the cluster where the VM(s) will be created using a template.



29
30
31
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 29

def cluster_reference
  @cluster_reference
end

#number_of_vmsObject

Number of VMs to be deployed.



23
24
25
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 23

def number_of_vms
  @number_of_vms
end

#override_vm_config_mapObject

The map specifies the VM configuration overrides for each of the specified VM(s) to be created. The overrides can include the created VM Name, configuration and guest customization. For each VM to be created, the map has the index of the VM as the key and the corresponding VM override configurations as the value.



26
27
28
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 26

def override_vm_config_map
  @override_vm_config_map
end

#version_idObject

The identifier of a version.



20
21
22
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 20

def version_id
  @version_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 32

def self.attribute_map
  {
    :'version_id' => :'versionId',
    :'number_of_vms' => :'numberOfVms',
    :'override_vm_config_map' => :'overrideVmConfigMap',
    :'cluster_reference' => :'clusterReference'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 52

def self.openapi_types
  {
    :'version_id' => :'String',
    :'number_of_vms' => :'Integer',
    :'override_vm_config_map' => :'Hash<String, VmmV40ContentVmConfigOverride>',
    :'cluster_reference' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
210
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version_id == o.version_id &&
      number_of_vms == o.number_of_vms &&
      override_vm_config_map == o.override_vm_config_map &&
      cluster_reference == o.cluster_reference
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 220

def hash
  [version_id, number_of_vms, override_vm_config_map, cluster_reference].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@version_id.nil? && @version_id !~ pattern
    invalid_properties.push("invalid value for \"version_id\", must conform to the pattern #{pattern}.")
  end

  if @number_of_vms.nil?
    invalid_properties.push('invalid value for "number_of_vms", number_of_vms cannot be nil.')
  end

  if @number_of_vms > 250
    invalid_properties.push('invalid value for "number_of_vms", must be smaller than or equal to 250.')
  end

  if @number_of_vms < 1
    invalid_properties.push('invalid value for "number_of_vms", must be greater than or equal to 1.')
  end

  if @cluster_reference.nil?
    invalid_properties.push('invalid value for "cluster_reference", cluster_reference cannot be nil.')
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if @cluster_reference !~ pattern
    invalid_properties.push("invalid value for \"cluster_reference\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
148
149
150
151
# File 'lib/nutanix_vmm/models/vmm_v40_content_template_deployment.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@version_id.nil? && @version_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if @number_of_vms.nil?
  return false if @number_of_vms > 250
  return false if @number_of_vms < 1
  return false if @cluster_reference.nil?
  return false if @cluster_reference !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  true
end