Class: NutanixVmm::VmmV40ContentUrlSource

Inherits:
ApiModelBase show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_content_url_source.rb

Overview

The source URL details for creating an image.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40ContentUrlSource

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ContentUrlSource` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ContentUrlSource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'should_allow_insecure_url')
    self.should_allow_insecure_url = attributes[:'should_allow_insecure_url']
  else
    self.should_allow_insecure_url = false
  end

  if attributes.key?(:'basic_auth')
    self.basic_auth = attributes[:'basic_auth']
  end
end

Instance Attribute Details

#basic_authObject

Returns the value of attribute basic_auth.



25
26
27
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 25

def basic_auth
  @basic_auth
end

#should_allow_insecure_urlObject

Ignore the certificate errors if the value is true. Default is false.



23
24
25
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 23

def should_allow_insecure_url
  @should_allow_insecure_url
end

#urlObject

The URL for creating an image.



20
21
22
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 20

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 28

def self.attribute_map
  {
    :'url' => :'url',
    :'should_allow_insecure_url' => :'shouldAllowInsecureUrl',
    :'basic_auth' => :'basicAuth'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 47

def self.openapi_types
  {
    :'url' => :'String',
    :'should_allow_insecure_url' => :'Boolean',
    :'basic_auth' => :'VmmV40ContentUrlBasicAuth'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



137
138
139
140
141
142
143
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 137

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url == o.url &&
      should_allow_insecure_url == o.should_allow_insecure_url &&
      basic_auth == o.basic_auth
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 147

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



153
154
155
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 153

def hash
  [url, should_allow_insecure_url, basic_auth].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 96

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  pattern = Regexp.new(/^((http[s]?|nfs):\/)?\/?([^:\/\s]*)((\/\w+)*(:[0-9]+)*?\/)([\w\-\.]+[^#?\s]+)(.*)?(#[\w\-]+)?$/)
  if @url !~ pattern
    invalid_properties.push("invalid value for \"url\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



113
114
115
116
117
118
# File 'lib/nutanix_vmm/models/vmm_v40_content_url_source.rb', line 113

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @url.nil?
  return false if @url !~ Regexp.new(/^((http[s]?|nfs):\/)?\/?([^:\/\s]*)((\/\w+)*(:[0-9]+)*?\/)([\w\-\.]+[^#?\s]+)(.*)?(#[\w\-]+)?$/)
  true
end