Class: NutanixVmm::VmmV40EsxiConfigCdRomBackingInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40EsxiConfigCdRomBackingInfo
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb
Overview
Storage provided by Nutanix ADSF.
Instance Attribute Summary collapse
-
#disk_ext_id ⇒ Object
A globally unique identifier of a VM disk of type UUID.
-
#storage_container ⇒ Object
Returns the value of attribute storage_container.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40EsxiConfigCdRomBackingInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40EsxiConfigCdRomBackingInfo
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40EsxiConfigCdRomBackingInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40EsxiConfigCdRomBackingInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'disk_ext_id') self.disk_ext_id = attributes[:'disk_ext_id'] end if attributes.key?(:'storage_container') self.storage_container = attributes[:'storage_container'] end end |
Instance Attribute Details
#disk_ext_id ⇒ Object
A globally unique identifier of a VM disk of type UUID.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 20 def disk_ext_id @disk_ext_id end |
#storage_container ⇒ Object
Returns the value of attribute storage_container.
22 23 24 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 22 def storage_container @storage_container end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 25 def self.attribute_map { :'disk_ext_id' => :'diskExtId', :'storage_container' => :'storageContainer' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 141 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 43 def self.openapi_types { :'disk_ext_id' => :'String', :'storage_container' => :'VmmV40EsxiConfigVmDiskContainerReference' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 119 def ==(o) return true if self.equal?(o) self.class == o.class && disk_ext_id == o.disk_ext_id && storage_container == o.storage_container end |
#eql?(o) ⇒ Boolean
128 129 130 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 128 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 134 def hash [disk_ext_id, storage_container].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
83 84 85 86 87 88 89 90 91 92 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 83 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@disk_ext_id.nil? && @disk_ext_id !~ pattern invalid_properties.push("invalid value for \"disk_ext_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
96 97 98 99 100 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_cd_rom_backing_info.rb', line 96 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@disk_ext_id.nil? && @disk_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) true end |