Class: NutanixVmm::VmmV40EsxiConfigNicBackingInfo

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb

Overview

Information about how NIC is emulated.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40EsxiConfigNicBackingInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40EsxiConfigNicBackingInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40EsxiConfigNicBackingInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'mac_address')
    self.mac_address = attributes[:'mac_address']
  end

  if attributes.key?(:'is_connected')
    self.is_connected = attributes[:'is_connected']
  else
    self.is_connected = true
  end

  if attributes.key?(:'adapter_type')
    self.adapter_type = attributes[:'adapter_type']
  end
end

Instance Attribute Details

#adapter_typeObject

Returns the value of attribute adapter_type.



25
26
27
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 25

def adapter_type
  @adapter_type
end

#is_connectedObject

Indicates whether the NIC is connected or not. Default is True.



23
24
25
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 23

def is_connected
  @is_connected
end

#mac_addressObject

MAC address of the NIC.



20
21
22
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 20

def mac_address
  @mac_address
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 50

def self.attribute_map
  {
    :'mac_address' => :'macAddress',
    :'is_connected' => :'isConnected',
    :'adapter_type' => :'adapterType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 69

def self.openapi_types
  {
    :'mac_address' => :'String',
    :'is_connected' => :'Boolean',
    :'adapter_type' => :'VmmV40EsxiConfigAdapterType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      mac_address == o.mac_address &&
      is_connected == o.is_connected &&
      adapter_type == o.adapter_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 168

def hash
  [mac_address, is_connected, adapter_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
121
122
123
124
125
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/)
  if !@mac_address.nil? && @mac_address !~ pattern
    invalid_properties.push("invalid value for \"mac_address\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_config_nic_backing_info.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@mac_address.nil? && @mac_address !~ Regexp.new(/^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/)
  true
end