Class: NutanixVmm::VmmV40ImagesConfigPlacementPolicy

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VmmV40ImagesConfigPlacementPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ImagesConfigPlacementPolicy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ImagesConfigPlacementPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'ext_id')
    self.ext_id = attributes[:'ext_id']
  end

  if attributes.key?(:'links')
    if (value = attributes[:'links']).is_a?(Array)
      self.links = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'placement_type')
    self.placement_type = attributes[:'placement_type']
  else
    self.placement_type = nil
  end

  if attributes.key?(:'image_entity_filter')
    self.image_entity_filter = attributes[:'image_entity_filter']
  else
    self.image_entity_filter = nil
  end

  if attributes.key?(:'cluster_entity_filter')
    self.cluster_entity_filter = attributes[:'cluster_entity_filter']
  else
    self.cluster_entity_filter = nil
  end

  if attributes.key?(:'enforcement_state')
    self.enforcement_state = attributes[:'enforcement_state']
  end

  if attributes.key?(:'create_time')
    self.create_time = attributes[:'create_time']
  end

  if attributes.key?(:'last_update_time')
    self.last_update_time = attributes[:'last_update_time']
  end

  if attributes.key?(:'owner_ext_id')
    self.owner_ext_id = attributes[:'owner_ext_id']
  end
end

Instance Attribute Details

#cluster_entity_filterObject

Returns the value of attribute cluster_entity_filter.



37
38
39
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 37

def cluster_entity_filter
  @cluster_entity_filter
end

#create_timeObject

Image placement policy creation time.



42
43
44
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 42

def create_time
  @create_time
end

#descriptionObject

Description of the image placement policy.



31
32
33
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 31

def description
  @description
end

#enforcement_stateObject

Returns the value of attribute enforcement_state.



39
40
41
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 39

def enforcement_state
  @enforcement_state
end

#ext_idObject

A globally unique identifier of an instance that is suitable for external consumption.



22
23
24
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 22

def ext_id
  @ext_id
end

#image_entity_filterObject

Returns the value of attribute image_entity_filter.



35
36
37
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 35

def image_entity_filter
  @image_entity_filter
end

#last_update_timeObject

Last updated time of an image placement policy.



45
46
47
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 45

def last_update_time
  @last_update_time
end

A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.



25
26
27
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 25

def links
  @links
end

#nameObject

Name of the image placement policy.



28
29
30
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 28

def name
  @name
end

#owner_ext_idObject

External identifier of the owner of the image placement policy.



48
49
50
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 48

def owner_ext_id
  @owner_ext_id
end

#placement_typeObject

Returns the value of attribute placement_type.



33
34
35
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 33

def placement_type
  @placement_type
end

#tenant_idObject

A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).



19
20
21
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 19

def tenant_id
  @tenant_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



91
92
93
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 91

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



96
97
98
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 96

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 73

def self.attribute_map
  {
    :'tenant_id' => :'tenantId',
    :'ext_id' => :'extId',
    :'links' => :'links',
    :'name' => :'name',
    :'description' => :'description',
    :'placement_type' => :'placementType',
    :'image_entity_filter' => :'imageEntityFilter',
    :'cluster_entity_filter' => :'clusterEntityFilter',
    :'enforcement_state' => :'enforcementState',
    :'create_time' => :'createTime',
    :'last_update_time' => :'lastUpdateTime',
    :'owner_ext_id' => :'ownerExtId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 440

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



126
127
128
129
130
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 126

def self.openapi_all_of
  [
  :'CommonV10ResponseExternalizableAbstractModel'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
123
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 119

def self.openapi_nullable
  Set.new([
    :'ext_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 101

def self.openapi_types
  {
    :'tenant_id' => :'String',
    :'ext_id' => :'String',
    :'links' => :'Array<CommonV10ResponseApiLink>',
    :'name' => :'String',
    :'description' => :'String',
    :'placement_type' => :'VmmV40ImagesConfigPlacementType',
    :'image_entity_filter' => :'VmmV40ImagesConfigFilter',
    :'cluster_entity_filter' => :'VmmV40ImagesConfigFilter',
    :'enforcement_state' => :'VmmV40ImagesConfigEnforcementState',
    :'create_time' => :'Time',
    :'last_update_time' => :'Time',
    :'owner_ext_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 408

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tenant_id == o.tenant_id &&
      ext_id == o.ext_id &&
      links == o.links &&
      name == o.name &&
      description == o.description &&
      placement_type == o.placement_type &&
      image_entity_filter == o.image_entity_filter &&
      cluster_entity_filter == o.cluster_entity_filter &&
      enforcement_state == o.enforcement_state &&
      create_time == o.create_time &&
      last_update_time == o.last_update_time &&
      owner_ext_id == o.owner_ext_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


427
428
429
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 427

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



433
434
435
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 433

def hash
  [tenant_id, ext_id, links, name, description, placement_type, image_entity_filter, cluster_entity_filter, enforcement_state, create_time, last_update_time, owner_ext_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 209

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@tenant_id.nil? && @tenant_id !~ pattern
    invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@ext_id.nil? && @ext_id !~ pattern
    invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.")
  end

  if !@links.nil? && @links.length > 20
    invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.')
  end

  if !@links.nil? && @links.length < 0
    invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 256
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length > 1000
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.')
  end

  if @placement_type.nil?
    invalid_properties.push('invalid value for "placement_type", placement_type cannot be nil.')
  end

  if @image_entity_filter.nil?
    invalid_properties.push('invalid value for "image_entity_filter", image_entity_filter cannot be nil.')
  end

  if @cluster_entity_filter.nil?
    invalid_properties.push('invalid value for "cluster_entity_filter", cluster_entity_filter cannot be nil.')
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@owner_ext_id.nil? && @owner_ext_id !~ pattern
    invalid_properties.push("invalid value for \"owner_ext_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 462

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_placement_policy.rb', line 268

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@links.nil? && @links.length > 20
  return false if !@links.nil? && @links.length < 0
  return false if @name.nil?
  return false if @name.to_s.length > 256
  return false if @name.to_s.length < 1
  return false if !@description.nil? && @description.to_s.length > 1000
  return false if @placement_type.nil?
  return false if @image_entity_filter.nil?
  return false if @cluster_entity_filter.nil?
  return false if !@owner_ext_id.nil? && @owner_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  true
end