Class: NutanixVmm::CommonV10ConfigIPv4Address
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::CommonV10ConfigIPv4Address
- Defined in:
- lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb
Overview
An unique address that identifies a device on the internet or a local network in IPv4 format.
Instance Attribute Summary collapse
-
#prefix_length ⇒ Object
The prefix length of the network to which this host IPv4 address belongs.
-
#value ⇒ Object
The IPv4 address of the host.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommonV10ConfigIPv4Address
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CommonV10ConfigIPv4Address
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::CommonV10ConfigIPv4Address` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::CommonV10ConfigIPv4Address`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'prefix_length') self.prefix_length = attributes[:'prefix_length'] else self.prefix_length = 32 end end |
Instance Attribute Details
#prefix_length ⇒ Object
The prefix length of the network to which this host IPv4 address belongs.
23 24 25 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 23 def prefix_length @prefix_length end |
#value ⇒ Object
The IPv4 address of the host.
20 21 22 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 20 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 26 def self.attribute_map { :'value' => :'value', :'prefix_length' => :'prefixLength' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 179 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 44 def self.openapi_types { :'value' => :'String', :'prefix_length' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && value == o.value && prefix_length == o.prefix_length end |
#eql?(o) ⇒ Boolean
166 167 168 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 166 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 172 def hash [value, prefix_length].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 88 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end pattern = Regexp.new(/^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/) if @value !~ pattern invalid_properties.push("invalid value for \"value\", must conform to the pattern #{pattern}.") end if !@prefix_length.nil? && @prefix_length > 32 invalid_properties.push('invalid value for "prefix_length", must be smaller than or equal to 32.') end if !@prefix_length.nil? && @prefix_length < 0 invalid_properties.push('invalid value for "prefix_length", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 116 117 118 119 120 |
# File 'lib/nutanix_vmm/models/common_v10_config_ipv4_address.rb', line 113 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @value.nil? return false if @value !~ Regexp.new(/^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/) return false if !@prefix_length.nil? && @prefix_length > 32 return false if !@prefix_length.nil? && @prefix_length < 0 true end |