Class: NutanixVmm::VmHostAffinityPoliciesApi
- Inherits:
-
Object
- Object
- NutanixVmm::VmHostAffinityPoliciesApi
- Defined in:
- lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_vm_host_affinity_policy(ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) ⇒ CreateVmHostAffinityPolicy202Response
Create a new VM-host affinity policy Creates a new VM-host affinity policy with the provided configuration.
-
#create_vm_host_affinity_policy_with_http_info(ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) ⇒ Array<(CreateVmHostAffinityPolicy202Response, Integer, Hash)>
Create a new VM-host affinity policy Creates a new VM-host affinity policy with the provided configuration.
-
#delete_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, opts = {}) ⇒ DeleteVmHostAffinityPolicyById202Response
Delete a VM-host affinity policy Deletes the VM-host affinity policy with the given external identifier.
-
#delete_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, opts = {}) ⇒ Array<(DeleteVmHostAffinityPolicyById202Response, Integer, Hash)>
Delete a VM-host affinity policy Deletes the VM-host affinity policy with the given external identifier.
-
#get_vm_host_affinity_policy_by_id(ext_id, opts = {}) ⇒ GetVmHostAffinityPolicyById200Response
Get the VM-host affinity policy details Fetches the VM-host affinity policy configuration for the provided VM-host affinity policy external identifier.
-
#get_vm_host_affinity_policy_by_id_with_http_info(ext_id, opts = {}) ⇒ Array<(GetVmHostAffinityPolicyById200Response, Integer, Hash)>
Get the VM-host affinity policy details Fetches the VM-host affinity policy configuration for the provided VM-host affinity policy external identifier.
-
#initialize(api_client = ApiClient.default) ⇒ VmHostAffinityPoliciesApi
constructor
A new instance of VmHostAffinityPoliciesApi.
-
#list_vm_host_affinity_policies(opts = {}) ⇒ ListVmHostAffinityPolicies200Response
List all the VM-Host Affinity policies Lists all the VM-Host Affinity policies.
-
#list_vm_host_affinity_policies_with_http_info(opts = {}) ⇒ Array<(ListVmHostAffinityPolicies200Response, Integer, Hash)>
List all the VM-Host Affinity policies Lists all the VM-Host Affinity policies.
-
#list_vm_host_affinity_policy_vm_compliance_states(vm_host_affinity_policy_ext_id, opts = {}) ⇒ ListVmHostAffinityPolicyVmComplianceStates200Response
List the VM compliance states of the VM-host affinity policy Lists the compliance state of all the VMs associated with the VM-host affinity policy.
-
#list_vm_host_affinity_policy_vm_compliance_states_with_http_info(vm_host_affinity_policy_ext_id, opts = {}) ⇒ Array<(ListVmHostAffinityPolicyVmComplianceStates200Response, Integer, Hash)>
List the VM compliance states of the VM-host affinity policy Lists the compliance state of all the VMs associated with the VM-host affinity policy.
-
#re_enforce_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, opts = {}) ⇒ ReEnforceVmHostAffinityPolicyById202Response
Re-enforce the VM-host affinity policy Re-enforces the VM-host affinity policy on all the VMs associated with the policy.
-
#re_enforce_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, opts = {}) ⇒ Array<(ReEnforceVmHostAffinityPolicyById202Response, Integer, Hash)>
Re-enforce the VM-host affinity policy Re-enforces the VM-host affinity policy on all the VMs associated with the policy.
-
#update_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) ⇒ UpdateVmHostAffinityPolicyById202Response
Update the VM-host affinity policy Updates the configuration of the VM-host affinity policy with the given external identifier.
-
#update_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) ⇒ Array<(UpdateVmHostAffinityPolicyById202Response, Integer, Hash)>
Update the VM-host affinity policy Updates the configuration of the VM-host affinity policy with the given external identifier.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ VmHostAffinityPoliciesApi
Returns a new instance of VmHostAffinityPoliciesApi.
19 20 21 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_vm_host_affinity_policy(ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) ⇒ CreateVmHostAffinityPolicy202Response
Create a new VM-host affinity policy Creates a new VM-host affinity policy with the provided configuration.
28 29 30 31 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 28 def create_vm_host_affinity_policy(ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) data, _status_code, _headers = create_vm_host_affinity_policy_with_http_info(ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts) data end |
#create_vm_host_affinity_policy_with_http_info(ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) ⇒ Array<(CreateVmHostAffinityPolicy202Response, Integer, Hash)>
Create a new VM-host affinity policy Creates a new VM-host affinity policy with the provided configuration.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 39 def create_vm_host_affinity_policy_with_http_info(ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VmHostAffinityPoliciesApi.create_vm_host_affinity_policy ...' end # verify the required parameter 'ntnx_request_id' is set if @api_client.config.client_side_validation && ntnx_request_id.nil? fail ArgumentError, "Missing the required parameter 'ntnx_request_id' when calling VmHostAffinityPoliciesApi.create_vm_host_affinity_policy" end # verify the required parameter 'vmm_v40_ahv_policies_vm_host_affinity_policy' is set if @api_client.config.client_side_validation && vmm_v40_ahv_policies_vm_host_affinity_policy.nil? fail ArgumentError, "Missing the required parameter 'vmm_v40_ahv_policies_vm_host_affinity_policy' when calling VmHostAffinityPoliciesApi.create_vm_host_affinity_policy" end # resource path local_var_path = '/vmm/v4.0/ahv/policies/vm-host-affinity-policies' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'NTNX-Request-Id'] = ntnx_request_id # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(vmm_v40_ahv_policies_vm_host_affinity_policy) # return_type return_type = opts[:debug_return_type] || 'CreateVmHostAffinityPolicy202Response' # auth_names auth_names = opts[:debug_auth_names] || ['apiKeyAuthScheme', 'basicAuthScheme'] = opts.merge( :operation => :"VmHostAffinityPoliciesApi.create_vm_host_affinity_policy", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VmHostAffinityPoliciesApi#create_vm_host_affinity_policy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, opts = {}) ⇒ DeleteVmHostAffinityPolicyById202Response
Delete a VM-host affinity policy Deletes the VM-host affinity policy with the given external identifier.
104 105 106 107 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 104 def delete_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, opts = {}) data, _status_code, _headers = delete_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, opts) data end |
#delete_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, opts = {}) ⇒ Array<(DeleteVmHostAffinityPolicyById202Response, Integer, Hash)>
Delete a VM-host affinity policy Deletes the VM-host affinity policy with the given external identifier.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 116 def delete_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VmHostAffinityPoliciesApi.delete_vm_host_affinity_policy_by_id ...' end # verify the required parameter 'ext_id' is set if @api_client.config.client_side_validation && ext_id.nil? fail ArgumentError, "Missing the required parameter 'ext_id' when calling VmHostAffinityPoliciesApi.delete_vm_host_affinity_policy_by_id" end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if @api_client.config.client_side_validation && ext_id !~ pattern fail ArgumentError, "invalid value for 'ext_id' when calling VmHostAffinityPoliciesApi.delete_vm_host_affinity_policy_by_id, must conform to the pattern #{pattern}." end # verify the required parameter 'if_match' is set if @api_client.config.client_side_validation && if_match.nil? fail ArgumentError, "Missing the required parameter 'if_match' when calling VmHostAffinityPoliciesApi.delete_vm_host_affinity_policy_by_id" end # verify the required parameter 'ntnx_request_id' is set if @api_client.config.client_side_validation && ntnx_request_id.nil? fail ArgumentError, "Missing the required parameter 'ntnx_request_id' when calling VmHostAffinityPoliciesApi.delete_vm_host_affinity_policy_by_id" end # resource path local_var_path = '/vmm/v4.0/ahv/policies/vm-host-affinity-policies/{extId}'.sub('{' + 'extId' + '}', CGI.escape(ext_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'If-Match'] = if_match header_params[:'NTNX-Request-Id'] = ntnx_request_id # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteVmHostAffinityPolicyById202Response' # auth_names auth_names = opts[:debug_auth_names] || ['apiKeyAuthScheme', 'basicAuthScheme'] = opts.merge( :operation => :"VmHostAffinityPoliciesApi.delete_vm_host_affinity_policy_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VmHostAffinityPoliciesApi#delete_vm_host_affinity_policy_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_vm_host_affinity_policy_by_id(ext_id, opts = {}) ⇒ GetVmHostAffinityPolicyById200Response
Get the VM-host affinity policy details Fetches the VM-host affinity policy configuration for the provided VM-host affinity policy external identifier.
184 185 186 187 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 184 def get_vm_host_affinity_policy_by_id(ext_id, opts = {}) data, _status_code, _headers = get_vm_host_affinity_policy_by_id_with_http_info(ext_id, opts) data end |
#get_vm_host_affinity_policy_by_id_with_http_info(ext_id, opts = {}) ⇒ Array<(GetVmHostAffinityPolicyById200Response, Integer, Hash)>
Get the VM-host affinity policy details Fetches the VM-host affinity policy configuration for the provided VM-host affinity policy external identifier.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 194 def get_vm_host_affinity_policy_by_id_with_http_info(ext_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VmHostAffinityPoliciesApi.get_vm_host_affinity_policy_by_id ...' end # verify the required parameter 'ext_id' is set if @api_client.config.client_side_validation && ext_id.nil? fail ArgumentError, "Missing the required parameter 'ext_id' when calling VmHostAffinityPoliciesApi.get_vm_host_affinity_policy_by_id" end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if @api_client.config.client_side_validation && ext_id !~ pattern fail ArgumentError, "invalid value for 'ext_id' when calling VmHostAffinityPoliciesApi.get_vm_host_affinity_policy_by_id, must conform to the pattern #{pattern}." end # resource path local_var_path = '/vmm/v4.0/ahv/policies/vm-host-affinity-policies/{extId}'.sub('{' + 'extId' + '}', CGI.escape(ext_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetVmHostAffinityPolicyById200Response' # auth_names auth_names = opts[:debug_auth_names] || ['apiKeyAuthScheme', 'basicAuthScheme'] = opts.merge( :operation => :"VmHostAffinityPoliciesApi.get_vm_host_affinity_policy_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VmHostAffinityPoliciesApi#get_vm_host_affinity_policy_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_vm_host_affinity_policies(opts = {}) ⇒ ListVmHostAffinityPolicies200Response
List all the VM-Host Affinity policies Lists all the VM-Host Affinity policies.
255 256 257 258 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 255 def list_vm_host_affinity_policies(opts = {}) data, _status_code, _headers = list_vm_host_affinity_policies_with_http_info(opts) data end |
#list_vm_host_affinity_policies_with_http_info(opts = {}) ⇒ Array<(ListVmHostAffinityPolicies200Response, Integer, Hash)>
List all the VM-Host Affinity policies Lists all the VM-Host Affinity policies.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 268 def list_vm_host_affinity_policies_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VmHostAffinityPoliciesApi.list_vm_host_affinity_policies ...' end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 0 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling VmHostAffinityPoliciesApi.list_vm_host_affinity_policies, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling VmHostAffinityPoliciesApi.list_vm_host_affinity_policies, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling VmHostAffinityPoliciesApi.list_vm_host_affinity_policies, must be greater than or equal to 1.' end # resource path local_var_path = '/vmm/v4.0/ahv/policies/vm-host-affinity-policies' # query parameters query_params = opts[:query_params] || {} query_params[:'$page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'$limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'$filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'$orderby'] = opts[:'orderby'] if !opts[:'orderby'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListVmHostAffinityPolicies200Response' # auth_names auth_names = opts[:debug_auth_names] || ['apiKeyAuthScheme', 'basicAuthScheme'] = opts.merge( :operation => :"VmHostAffinityPoliciesApi.list_vm_host_affinity_policies", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VmHostAffinityPoliciesApi#list_vm_host_affinity_policies\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_vm_host_affinity_policy_vm_compliance_states(vm_host_affinity_policy_ext_id, opts = {}) ⇒ ListVmHostAffinityPolicyVmComplianceStates200Response
List the VM compliance states of the VM-host affinity policy Lists the compliance state of all the VMs associated with the VM-host affinity policy.
335 336 337 338 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 335 def list_vm_host_affinity_policy_vm_compliance_states(vm_host_affinity_policy_ext_id, opts = {}) data, _status_code, _headers = list_vm_host_affinity_policy_vm_compliance_states_with_http_info(vm_host_affinity_policy_ext_id, opts) data end |
#list_vm_host_affinity_policy_vm_compliance_states_with_http_info(vm_host_affinity_policy_ext_id, opts = {}) ⇒ Array<(ListVmHostAffinityPolicyVmComplianceStates200Response, Integer, Hash)>
List the VM compliance states of the VM-host affinity policy Lists the compliance state of all the VMs associated with the VM-host affinity policy.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 347 def list_vm_host_affinity_policy_vm_compliance_states_with_http_info(vm_host_affinity_policy_ext_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VmHostAffinityPoliciesApi.list_vm_host_affinity_policy_vm_compliance_states ...' end # verify the required parameter 'vm_host_affinity_policy_ext_id' is set if @api_client.config.client_side_validation && vm_host_affinity_policy_ext_id.nil? fail ArgumentError, "Missing the required parameter 'vm_host_affinity_policy_ext_id' when calling VmHostAffinityPoliciesApi.list_vm_host_affinity_policy_vm_compliance_states" end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if @api_client.config.client_side_validation && vm_host_affinity_policy_ext_id !~ pattern fail ArgumentError, "invalid value for 'vm_host_affinity_policy_ext_id' when calling VmHostAffinityPoliciesApi.list_vm_host_affinity_policy_vm_compliance_states, must conform to the pattern #{pattern}." end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 0 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling VmHostAffinityPoliciesApi.list_vm_host_affinity_policy_vm_compliance_states, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling VmHostAffinityPoliciesApi.list_vm_host_affinity_policy_vm_compliance_states, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling VmHostAffinityPoliciesApi.list_vm_host_affinity_policy_vm_compliance_states, must be greater than or equal to 1.' end # resource path local_var_path = '/vmm/v4.0/ahv/policies/vm-host-affinity-policies/{vmHostAffinityPolicyExtId}/vm-compliance-states'.sub('{' + 'vmHostAffinityPolicyExtId' + '}', CGI.escape(vm_host_affinity_policy_ext_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'$page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'$limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListVmHostAffinityPolicyVmComplianceStates200Response' # auth_names auth_names = opts[:debug_auth_names] || ['apiKeyAuthScheme', 'basicAuthScheme'] = opts.merge( :operation => :"VmHostAffinityPoliciesApi.list_vm_host_affinity_policy_vm_compliance_states", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VmHostAffinityPoliciesApi#list_vm_host_affinity_policy_vm_compliance_states\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#re_enforce_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, opts = {}) ⇒ ReEnforceVmHostAffinityPolicyById202Response
Re-enforce the VM-host affinity policy Re-enforces the VM-host affinity policy on all the VMs associated with the policy.
421 422 423 424 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 421 def re_enforce_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, opts = {}) data, _status_code, _headers = re_enforce_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, opts) data end |
#re_enforce_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, opts = {}) ⇒ Array<(ReEnforceVmHostAffinityPolicyById202Response, Integer, Hash)>
Re-enforce the VM-host affinity policy Re-enforces the VM-host affinity policy on all the VMs associated with the policy.
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 433 def re_enforce_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VmHostAffinityPoliciesApi.re_enforce_vm_host_affinity_policy_by_id ...' end # verify the required parameter 'ext_id' is set if @api_client.config.client_side_validation && ext_id.nil? fail ArgumentError, "Missing the required parameter 'ext_id' when calling VmHostAffinityPoliciesApi.re_enforce_vm_host_affinity_policy_by_id" end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if @api_client.config.client_side_validation && ext_id !~ pattern fail ArgumentError, "invalid value for 'ext_id' when calling VmHostAffinityPoliciesApi.re_enforce_vm_host_affinity_policy_by_id, must conform to the pattern #{pattern}." end # verify the required parameter 'if_match' is set if @api_client.config.client_side_validation && if_match.nil? fail ArgumentError, "Missing the required parameter 'if_match' when calling VmHostAffinityPoliciesApi.re_enforce_vm_host_affinity_policy_by_id" end # verify the required parameter 'ntnx_request_id' is set if @api_client.config.client_side_validation && ntnx_request_id.nil? fail ArgumentError, "Missing the required parameter 'ntnx_request_id' when calling VmHostAffinityPoliciesApi.re_enforce_vm_host_affinity_policy_by_id" end # resource path local_var_path = '/vmm/v4.0/ahv/policies/vm-host-affinity-policies/{extId}/$actions/re-enforce'.sub('{' + 'extId' + '}', CGI.escape(ext_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'If-Match'] = if_match header_params[:'NTNX-Request-Id'] = ntnx_request_id # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ReEnforceVmHostAffinityPolicyById202Response' # auth_names auth_names = opts[:debug_auth_names] || ['apiKeyAuthScheme', 'basicAuthScheme'] = opts.merge( :operation => :"VmHostAffinityPoliciesApi.re_enforce_vm_host_affinity_policy_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VmHostAffinityPoliciesApi#re_enforce_vm_host_affinity_policy_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) ⇒ UpdateVmHostAffinityPolicyById202Response
Update the VM-host affinity policy Updates the configuration of the VM-host affinity policy with the given external identifier.
504 505 506 507 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 504 def update_vm_host_affinity_policy_by_id(ext_id, if_match, ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) data, _status_code, _headers = update_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts) data end |
#update_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) ⇒ Array<(UpdateVmHostAffinityPolicyById202Response, Integer, Hash)>
Update the VM-host affinity policy Updates the configuration of the VM-host affinity policy with the given external identifier.
517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/nutanix_vmm/api/vm_host_affinity_policies_api.rb', line 517 def update_vm_host_affinity_policy_by_id_with_http_info(ext_id, if_match, ntnx_request_id, vmm_v40_ahv_policies_vm_host_affinity_policy, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VmHostAffinityPoliciesApi.update_vm_host_affinity_policy_by_id ...' end # verify the required parameter 'ext_id' is set if @api_client.config.client_side_validation && ext_id.nil? fail ArgumentError, "Missing the required parameter 'ext_id' when calling VmHostAffinityPoliciesApi.update_vm_host_affinity_policy_by_id" end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if @api_client.config.client_side_validation && ext_id !~ pattern fail ArgumentError, "invalid value for 'ext_id' when calling VmHostAffinityPoliciesApi.update_vm_host_affinity_policy_by_id, must conform to the pattern #{pattern}." end # verify the required parameter 'if_match' is set if @api_client.config.client_side_validation && if_match.nil? fail ArgumentError, "Missing the required parameter 'if_match' when calling VmHostAffinityPoliciesApi.update_vm_host_affinity_policy_by_id" end # verify the required parameter 'ntnx_request_id' is set if @api_client.config.client_side_validation && ntnx_request_id.nil? fail ArgumentError, "Missing the required parameter 'ntnx_request_id' when calling VmHostAffinityPoliciesApi.update_vm_host_affinity_policy_by_id" end # verify the required parameter 'vmm_v40_ahv_policies_vm_host_affinity_policy' is set if @api_client.config.client_side_validation && vmm_v40_ahv_policies_vm_host_affinity_policy.nil? fail ArgumentError, "Missing the required parameter 'vmm_v40_ahv_policies_vm_host_affinity_policy' when calling VmHostAffinityPoliciesApi.update_vm_host_affinity_policy_by_id" end # resource path local_var_path = '/vmm/v4.0/ahv/policies/vm-host-affinity-policies/{extId}'.sub('{' + 'extId' + '}', CGI.escape(ext_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'If-Match'] = if_match header_params[:'NTNX-Request-Id'] = ntnx_request_id # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(vmm_v40_ahv_policies_vm_host_affinity_policy) # return_type return_type = opts[:debug_return_type] || 'UpdateVmHostAffinityPolicyById202Response' # auth_names auth_names = opts[:debug_auth_names] || ['apiKeyAuthScheme', 'basicAuthScheme'] = opts.merge( :operation => :"VmHostAffinityPoliciesApi.update_vm_host_affinity_policy_by_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VmHostAffinityPoliciesApi#update_vm_host_affinity_policy_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |