Class: NutanixVmm::VmmV40AhvConfigCloneOverrideParams
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvConfigCloneOverrideParams
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb
Overview
VM clone override specification.
Instance Attribute Summary collapse
-
#boot_config ⇒ Object
Returns the value of attribute boot_config.
-
#guest_customization ⇒ Object
Returns the value of attribute guest_customization.
-
#memory_size_bytes ⇒ Object
Memory size in bytes.
-
#name ⇒ Object
VM name.
-
#nics ⇒ Object
NICs attached to the VM.
-
#num_cores_per_socket ⇒ Object
Number of cores per socket.
-
#num_sockets ⇒ Object
Number of vCPU sockets.
-
#num_threads_per_core ⇒ Object
Number of cores per socket.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvConfigCloneOverrideParams
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvConfigCloneOverrideParams
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigCloneOverrideParams` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigCloneOverrideParams`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'num_sockets') self.num_sockets = attributes[:'num_sockets'] end if attributes.key?(:'num_cores_per_socket') self.num_cores_per_socket = attributes[:'num_cores_per_socket'] end if attributes.key?(:'num_threads_per_core') self.num_threads_per_core = attributes[:'num_threads_per_core'] end if attributes.key?(:'memory_size_bytes') self.memory_size_bytes = attributes[:'memory_size_bytes'] end if attributes.key?(:'nics') if (value = attributes[:'nics']).is_a?(Array) self.nics = value end end if attributes.key?(:'boot_config') self.boot_config = attributes[:'boot_config'] end if attributes.key?(:'guest_customization') self.guest_customization = attributes[:'guest_customization'] end end |
Instance Attribute Details
#boot_config ⇒ Object
Returns the value of attribute boot_config.
37 38 39 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 37 def boot_config @boot_config end |
#guest_customization ⇒ Object
Returns the value of attribute guest_customization.
39 40 41 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 39 def guest_customization @guest_customization end |
#memory_size_bytes ⇒ Object
Memory size in bytes.
32 33 34 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 32 def memory_size_bytes @memory_size_bytes end |
#name ⇒ Object
VM name.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 20 def name @name end |
#nics ⇒ Object
NICs attached to the VM.
35 36 37 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 35 def nics @nics end |
#num_cores_per_socket ⇒ Object
Number of cores per socket.
26 27 28 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 26 def num_cores_per_socket @num_cores_per_socket end |
#num_sockets ⇒ Object
Number of vCPU sockets.
23 24 25 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 23 def num_sockets @num_sockets end |
#num_threads_per_core ⇒ Object
Number of cores per socket.
29 30 31 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 29 def num_threads_per_core @num_threads_per_core end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 42 def self.attribute_map { :'name' => :'name', :'num_sockets' => :'numSockets', :'num_cores_per_socket' => :'numCoresPerSocket', :'num_threads_per_core' => :'numThreadsPerCore', :'memory_size_bytes' => :'memorySizeBytes', :'nics' => :'nics', :'boot_config' => :'bootConfig', :'guest_customization' => :'guestCustomization' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 304 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 66 def self.openapi_types { :'name' => :'String', :'num_sockets' => :'Integer', :'num_cores_per_socket' => :'Integer', :'num_threads_per_core' => :'Integer', :'memory_size_bytes' => :'Integer', :'nics' => :'Array<VmmV40AhvConfigNic>', :'boot_config' => :'VmmV40AhvConfigCloneOverrideParamsBootConfig', :'guest_customization' => :'VmmV40AhvConfigGuestCustomizationParams' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 276 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && num_sockets == o.num_sockets && num_cores_per_socket == o.num_cores_per_socket && num_threads_per_core == o.num_threads_per_core && memory_size_bytes == o.memory_size_bytes && nics == o.nics && boot_config == o.boot_config && guest_customization == o.guest_customization end |
#eql?(o) ⇒ Boolean
291 292 293 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 291 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
297 298 299 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 297 def hash [name, num_sockets, num_cores_per_socket, num_threads_per_core, memory_size_bytes, nics, boot_config, guest_customization].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 80 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 80.') end if !@num_sockets.nil? && @num_sockets < 1 invalid_properties.push('invalid value for "num_sockets", must be greater than or equal to 1.') end if !@num_cores_per_socket.nil? && @num_cores_per_socket < 1 invalid_properties.push('invalid value for "num_cores_per_socket", must be greater than or equal to 1.') end if !@num_threads_per_core.nil? && @num_threads_per_core < 1 invalid_properties.push('invalid value for "num_threads_per_core", must be greater than or equal to 1.') end if !@memory_size_bytes.nil? && @memory_size_bytes < 1 invalid_properties.push('invalid value for "memory_size_bytes", must be greater than or equal to 1.') end if !@nics.nil? && @nics.length > 64 invalid_properties.push('invalid value for "nics", number of items must be less than or equal to 64.') end if !@nics.nil? && @nics.length < 0 invalid_properties.push('invalid value for "nics", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 326 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_clone_override_params.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 80 return false if !@num_sockets.nil? && @num_sockets < 1 return false if !@num_cores_per_socket.nil? && @num_cores_per_socket < 1 return false if !@num_threads_per_core.nil? && @num_threads_per_core < 1 return false if !@memory_size_bytes.nil? && @memory_size_bytes < 1 return false if !@nics.nil? && @nics.length > 64 return false if !@nics.nil? && @nics.length < 0 true end |