Class: NutanixVmm::VmmV40AhvConfigGpu
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvConfigGpu
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb
Overview
Graphics resource information for the virtual machine.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#device_id ⇒ Object
The device Id of the GPU.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#fraction ⇒ Object
Fraction of the physical GPU assigned.
-
#frame_buffer_size_bytes ⇒ Object
GPU frame buffer size in bytes.
-
#guest_driver_version ⇒ Object
Last determined guest driver version.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#name ⇒ Object
Name of the GPU resource.
-
#num_virtual_display_heads ⇒ Object
Number of supported virtual display heads.
-
#pci_address ⇒ Object
Returns the value of attribute pci_address.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
-
#vendor ⇒ Object
Returns the value of attribute vendor.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvConfigGpu
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvConfigGpu
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigGpu` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigGpu`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'device_id') self.device_id = attributes[:'device_id'] end if attributes.key?(:'vendor') self.vendor = attributes[:'vendor'] end if attributes.key?(:'pci_address') self.pci_address = attributes[:'pci_address'] end if attributes.key?(:'guest_driver_version') self.guest_driver_version = attributes[:'guest_driver_version'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'frame_buffer_size_bytes') self.frame_buffer_size_bytes = attributes[:'frame_buffer_size_bytes'] end if attributes.key?(:'num_virtual_display_heads') self.num_virtual_display_heads = attributes[:'num_virtual_display_heads'] end if attributes.key?(:'fraction') self.fraction = attributes[:'fraction'] end end |
Instance Attribute Details
#device_id ⇒ Object
The device Id of the GPU.
31 32 33 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 31 def device_id @device_id end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
23 24 25 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 23 def ext_id @ext_id end |
#fraction ⇒ Object
Fraction of the physical GPU assigned.
50 51 52 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 50 def fraction @fraction end |
#frame_buffer_size_bytes ⇒ Object
GPU frame buffer size in bytes.
44 45 46 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 44 def frame_buffer_size_bytes @frame_buffer_size_bytes end |
#guest_driver_version ⇒ Object
Last determined guest driver version.
38 39 40 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 38 def guest_driver_version @guest_driver_version end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
26 27 28 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 26 def links @links end |
#mode ⇒ Object
Returns the value of attribute mode.
28 29 30 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 28 def mode @mode end |
#name ⇒ Object
Name of the GPU resource.
41 42 43 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 41 def name @name end |
#num_virtual_display_heads ⇒ Object
Number of supported virtual display heads.
47 48 49 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 47 def num_virtual_display_heads @num_virtual_display_heads end |
#pci_address ⇒ Object
Returns the value of attribute pci_address.
35 36 37 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 35 def pci_address @pci_address end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 20 def tenant_id @tenant_id end |
#vendor ⇒ Object
Returns the value of attribute vendor.
33 34 35 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 33 def vendor @vendor end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
93 94 95 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 93 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 98 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 75 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'mode' => :'mode', :'device_id' => :'deviceId', :'vendor' => :'vendor', :'pci_address' => :'pciAddress', :'guest_driver_version' => :'guestDriverVersion', :'name' => :'name', :'frame_buffer_size_bytes' => :'frameBufferSizeBytes', :'num_virtual_display_heads' => :'numVirtualDisplayHeads', :'fraction' => :'fraction' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 354 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
128 129 130 131 132 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 128 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 125 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 121 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 103 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'mode' => :'VmmV40AhvConfigGpuMode', :'device_id' => :'Integer', :'vendor' => :'VmmV40AhvConfigGpuVendor', :'pci_address' => :'VmmV40AhvConfigSBDF', :'guest_driver_version' => :'String', :'name' => :'String', :'frame_buffer_size_bytes' => :'Integer', :'num_virtual_display_heads' => :'Integer', :'fraction' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 322 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && mode == o.mode && device_id == o.device_id && vendor == o.vendor && pci_address == o.pci_address && guest_driver_version == o.guest_driver_version && name == o.name && frame_buffer_size_bytes == o.frame_buffer_size_bytes && num_virtual_display_heads == o.num_virtual_display_heads && fraction == o.fraction end |
#eql?(o) ⇒ Boolean
341 342 343 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 341 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
347 348 349 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 347 def hash [tenant_id, ext_id, links, mode, device_id, vendor, pci_address, guest_driver_version, name, frame_buffer_size_bytes, num_virtual_display_heads, fraction].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 203 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if !@guest_driver_version.nil? && @guest_driver_version.to_s.length > 128 invalid_properties.push('invalid value for "guest_driver_version", the character length must be smaller than or equal to 128.') end if !@name.nil? && @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 376 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
237 238 239 240 241 242 243 244 245 246 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_gpu.rb', line 237 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@guest_driver_version.nil? && @guest_driver_version.to_s.length > 128 return false if !@name.nil? && @name.to_s.length > 128 true end |