Class: NutanixVmm::VmmV40AhvConfigUefiBoot
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvConfigUefiBoot
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb
Overview
UEFI boot mode and its associated configuration.
Instance Attribute Summary collapse
-
#boot_device ⇒ Object
Returns the value of attribute boot_device.
-
#boot_order ⇒ Object
Indicates the order of device types in which the VM should try to boot from.
-
#is_secure_boot_enabled ⇒ Object
Indicate whether to enable secure boot or not.
-
#nvram_device ⇒ Object
Returns the value of attribute nvram_device.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvConfigUefiBoot
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvConfigUefiBoot
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigUefiBoot` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigUefiBoot`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_secure_boot_enabled') self.is_secure_boot_enabled = attributes[:'is_secure_boot_enabled'] end if attributes.key?(:'nvram_device') self.nvram_device = attributes[:'nvram_device'] end if attributes.key?(:'boot_device') self.boot_device = attributes[:'boot_device'] end if attributes.key?(:'boot_order') if (value = attributes[:'boot_order']).is_a?(Array) self.boot_order = value end end end |
Instance Attribute Details
#boot_device ⇒ Object
Returns the value of attribute boot_device.
24 25 26 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 24 def boot_device @boot_device end |
#boot_order ⇒ Object
Indicates the order of device types in which the VM should try to boot from. If the boot device order is not provided the system will decide an appropriate boot device order.
27 28 29 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 27 def boot_order @boot_order end |
#is_secure_boot_enabled ⇒ Object
Indicate whether to enable secure boot or not.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 20 def is_secure_boot_enabled @is_secure_boot_enabled end |
#nvram_device ⇒ Object
Returns the value of attribute nvram_device.
22 23 24 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 22 def nvram_device @nvram_device end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 30 def self.attribute_map { :'is_secure_boot_enabled' => :'isSecureBootEnabled', :'nvram_device' => :'nvramDevice', :'boot_device' => :'bootDevice', :'boot_order' => :'bootOrder' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 50 def self.openapi_types { :'is_secure_boot_enabled' => :'Boolean', :'nvram_device' => :'VmmV40AhvConfigNvramDevice', :'boot_device' => :'VmmV40AhvConfigUefiBootBootDevice', :'boot_order' => :'Array<VmmV40AhvConfigBootDeviceType>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && is_secure_boot_enabled == o.is_secure_boot_enabled && nvram_device == o.nvram_device && boot_device == o.boot_device && boot_order == o.boot_order end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 162 def hash [is_secure_boot_enabled, nvram_device, boot_device, boot_order].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 102 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@boot_order.nil? && @boot_order.length > 3 invalid_properties.push('invalid value for "boot_order", number of items must be less than or equal to 3.') end if !@boot_order.nil? && @boot_order.length < 0 invalid_properties.push('invalid value for "boot_order", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
118 119 120 121 122 123 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_uefi_boot.rb', line 118 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@boot_order.nil? && @boot_order.length > 3 return false if !@boot_order.nil? && @boot_order.length < 0 true end |