Class: NutanixVmm::VmmV40AhvConfigVmDisk
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvConfigVmDisk
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb
Overview
Storage provided by Nutanix ADSF.
Instance Attribute Summary collapse
-
#data_source ⇒ Object
Returns the value of attribute data_source.
-
#disk_ext_id ⇒ Object
A globally unique identifier of a VM disk of type UUID.
-
#disk_size_bytes ⇒ Object
Size of the disk in bytes.
-
#is_migration_in_progress ⇒ Object
Indicates if the disk is undergoing migration to another container.
-
#storage_config ⇒ Object
Returns the value of attribute storage_config.
-
#storage_container ⇒ Object
Returns the value of attribute storage_container.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvConfigVmDisk
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvConfigVmDisk
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvConfigVmDisk` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvConfigVmDisk`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'disk_ext_id') self.disk_ext_id = attributes[:'disk_ext_id'] end if attributes.key?(:'disk_size_bytes') self.disk_size_bytes = attributes[:'disk_size_bytes'] end if attributes.key?(:'storage_container') self.storage_container = attributes[:'storage_container'] end if attributes.key?(:'storage_config') self.storage_config = attributes[:'storage_config'] end if attributes.key?(:'data_source') self.data_source = attributes[:'data_source'] end if attributes.key?(:'is_migration_in_progress') self.is_migration_in_progress = attributes[:'is_migration_in_progress'] end end |
Instance Attribute Details
#data_source ⇒ Object
Returns the value of attribute data_source.
29 30 31 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 29 def data_source @data_source end |
#disk_ext_id ⇒ Object
A globally unique identifier of a VM disk of type UUID.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 20 def disk_ext_id @disk_ext_id end |
#disk_size_bytes ⇒ Object
Size of the disk in bytes.
23 24 25 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 23 def disk_size_bytes @disk_size_bytes end |
#is_migration_in_progress ⇒ Object
Indicates if the disk is undergoing migration to another container.
32 33 34 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 32 def is_migration_in_progress @is_migration_in_progress end |
#storage_config ⇒ Object
Returns the value of attribute storage_config.
27 28 29 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 27 def storage_config @storage_config end |
#storage_container ⇒ Object
Returns the value of attribute storage_container.
25 26 27 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 25 def storage_container @storage_container end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 35 def self.attribute_map { :'disk_ext_id' => :'diskExtId', :'disk_size_bytes' => :'diskSizeBytes', :'storage_container' => :'storageContainer', :'storage_config' => :'storageConfig', :'data_source' => :'dataSource', :'is_migration_in_progress' => :'isMigrationInProgress' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 198 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 57 def self.openapi_types { :'disk_ext_id' => :'String', :'disk_size_bytes' => :'Integer', :'storage_container' => :'VmmV40AhvConfigVmDiskContainerReference', :'storage_config' => :'VmmV40AhvConfigVmDiskStorageConfig', :'data_source' => :'VmmV40AhvConfigDataSource', :'is_migration_in_progress' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && disk_ext_id == o.disk_ext_id && disk_size_bytes == o.disk_size_bytes && storage_container == o.storage_container && storage_config == o.storage_config && data_source == o.data_source && is_migration_in_progress == o.is_migration_in_progress end |
#eql?(o) ⇒ Boolean
185 186 187 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 185 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 191 def hash [disk_ext_id, disk_size_bytes, storage_container, storage_config, data_source, is_migration_in_progress].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@disk_ext_id.nil? && @disk_ext_id !~ pattern invalid_properties.push("invalid value for \"disk_ext_id\", must conform to the pattern #{pattern}.") end if !@disk_size_bytes.nil? && @disk_size_bytes < 1 invalid_properties.push('invalid value for "disk_size_bytes", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 139 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_config_vm_disk.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@disk_ext_id.nil? && @disk_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@disk_size_bytes.nil? && @disk_size_bytes < 1 true end |