Class: NutanixVmm::VmmV40AhvPoliciesVmAntiAffinityPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvPoliciesVmAntiAffinityPolicy
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb
Overview
VM-VM anti-affinity policy configuration.
Instance Attribute Summary collapse
-
#categories ⇒ Object
Categories configured for the VM-VM anti-affinity policy.
-
#create_time ⇒ Object
VM-VM anti-affinity policy creation time.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#description ⇒ Object
VM-VM anti-affinity policy description.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#name ⇒ Object
VM-VM anti-affinity policy name.
-
#num_compliant_vms ⇒ Object
Number of compliant VMs which are part of the VM-VM anti-affinity policy.
-
#num_non_compliant_vms ⇒ Object
Number of non-compliant VMs which are part of the VM-VM anti-affinity policy.
-
#num_pending_vms ⇒ Object
Number of VMs with compliance state as pending, which are part of the VM-VM anti-affinity policy.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
-
#update_time ⇒ Object
VM-VM anti-affinity policy last updated time.
-
#updated_by ⇒ Object
Returns the value of attribute updated_by.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvPoliciesVmAntiAffinityPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvPoliciesVmAntiAffinityPolicy
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvPoliciesVmAntiAffinityPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvPoliciesVmAntiAffinityPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'create_time') self.create_time = attributes[:'create_time'] end if attributes.key?(:'update_time') self.update_time = attributes[:'update_time'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] end if attributes.key?(:'categories') if (value = attributes[:'categories']).is_a?(Array) self.categories = value end end if attributes.key?(:'num_compliant_vms') self.num_compliant_vms = attributes[:'num_compliant_vms'] end if attributes.key?(:'num_non_compliant_vms') self.num_non_compliant_vms = attributes[:'num_non_compliant_vms'] end if attributes.key?(:'num_pending_vms') self.num_pending_vms = attributes[:'num_pending_vms'] end end |
Instance Attribute Details
#categories ⇒ Object
Categories configured for the VM-VM anti-affinity policy.
45 46 47 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 45 def categories @categories end |
#create_time ⇒ Object
VM-VM anti-affinity policy creation time.
35 36 37 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 35 def create_time @create_time end |
#created_by ⇒ Object
Returns the value of attribute created_by.
40 41 42 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 40 def created_by @created_by end |
#description ⇒ Object
VM-VM anti-affinity policy description.
32 33 34 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 32 def description @description end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
23 24 25 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 23 def ext_id @ext_id end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
26 27 28 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 26 def links @links end |
#name ⇒ Object
VM-VM anti-affinity policy name.
29 30 31 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 29 def name @name end |
#num_compliant_vms ⇒ Object
Number of compliant VMs which are part of the VM-VM anti-affinity policy.
48 49 50 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 48 def num_compliant_vms @num_compliant_vms end |
#num_non_compliant_vms ⇒ Object
Number of non-compliant VMs which are part of the VM-VM anti-affinity policy.
51 52 53 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 51 def num_non_compliant_vms @num_non_compliant_vms end |
#num_pending_vms ⇒ Object
Number of VMs with compliance state as pending, which are part of the VM-VM anti-affinity policy.
54 55 56 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 54 def num_pending_vms @num_pending_vms end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 20 def tenant_id @tenant_id end |
#update_time ⇒ Object
VM-VM anti-affinity policy last updated time.
38 39 40 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 38 def update_time @update_time end |
#updated_by ⇒ Object
Returns the value of attribute updated_by.
42 43 44 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 42 def updated_by @updated_by end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
76 77 78 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 76 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 81 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 57 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'name' => :'name', :'description' => :'description', :'create_time' => :'createTime', :'update_time' => :'updateTime', :'created_by' => :'createdBy', :'updated_by' => :'updatedBy', :'categories' => :'categories', :'num_compliant_vms' => :'numCompliantVms', :'num_non_compliant_vms' => :'numNonCompliantVms', :'num_pending_vms' => :'numPendingVms' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 363 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
112 113 114 115 116 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 112 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 105 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 86 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'name' => :'String', :'description' => :'String', :'create_time' => :'Time', :'update_time' => :'Time', :'created_by' => :'VmmV40AhvPoliciesUserReference', :'updated_by' => :'VmmV40AhvPoliciesUserReference', :'categories' => :'Array<VmmV40AhvPoliciesCategoryReference>', :'num_compliant_vms' => :'Integer', :'num_non_compliant_vms' => :'Integer', :'num_pending_vms' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 330 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && name == o.name && description == o.description && create_time == o.create_time && update_time == o.update_time && created_by == o.created_by && updated_by == o.updated_by && categories == o.categories && num_compliant_vms == o.num_compliant_vms && num_non_compliant_vms == o.num_non_compliant_vms && num_pending_vms == o.num_pending_vms end |
#eql?(o) ⇒ Boolean
350 351 352 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 350 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
356 357 358 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 356 def hash [tenant_id, ext_id, links, name, description, create_time, update_time, created_by, updated_by, categories, num_compliant_vms, num_non_compliant_vms, num_pending_vms].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 193 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if !@name.nil? && @name.to_s.length > 80 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 80.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@categories.nil? && @categories.length > 20 invalid_properties.push('invalid value for "categories", number of items must be less than or equal to 20.') end if !@categories.nil? && @categories.length < 1 invalid_properties.push('invalid value for "categories", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 385 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_anti_affinity_policy.rb', line 235 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@name.nil? && @name.to_s.length > 80 return false if !@name.nil? && @name.to_s.length < 1 return false if !@categories.nil? && @categories.length > 20 return false if !@categories.nil? && @categories.length < 1 true end |