Class: NutanixVmm::VmmV40AhvPoliciesVmHostAffinityPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvPoliciesVmHostAffinityPolicy
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb
Overview
VM-Host Affinity policy configuration.
Instance Attribute Summary collapse
-
#create_time ⇒ Object
VM-Host Affinity policy creation time.
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#description ⇒ Object
VM-Host Affinity policy description.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#host_categories ⇒ Object
Categories through which host is associated with the VM-host affinity policy.
-
#last_updated_by ⇒ Object
Returns the value of attribute last_updated_by.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#name ⇒ Object
VM-Host Affinity policy name.
-
#num_compliant_vms ⇒ Object
Number of VMs which are compliant with the VM-host affinity policy.
-
#num_hosts ⇒ Object
Number of hosts associated with the VM-host affinity policy.
-
#num_non_compliant_vms ⇒ Object
Number of VMs which are not compliant with the VM-host affinity policy.
-
#num_vms ⇒ Object
Number of VMs associated with the VM-host affinity policy.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
-
#update_time ⇒ Object
VM-Host Affinity policy last updated time.
-
#vm_categories ⇒ Object
Categories through which VM is associated with the VM-host affinity policy.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvPoliciesVmHostAffinityPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvPoliciesVmHostAffinityPolicy
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvPoliciesVmHostAffinityPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvPoliciesVmHostAffinityPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'create_time') self.create_time = attributes[:'create_time'] end if attributes.key?(:'update_time') self.update_time = attributes[:'update_time'] end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] end if attributes.key?(:'last_updated_by') self.last_updated_by = attributes[:'last_updated_by'] end if attributes.key?(:'vm_categories') if (value = attributes[:'vm_categories']).is_a?(Array) self.vm_categories = value end end if attributes.key?(:'host_categories') if (value = attributes[:'host_categories']).is_a?(Array) self.host_categories = value end end if attributes.key?(:'num_vms') self.num_vms = attributes[:'num_vms'] end if attributes.key?(:'num_hosts') self.num_hosts = attributes[:'num_hosts'] end if attributes.key?(:'num_compliant_vms') self.num_compliant_vms = attributes[:'num_compliant_vms'] end if attributes.key?(:'num_non_compliant_vms') self.num_non_compliant_vms = attributes[:'num_non_compliant_vms'] end end |
Instance Attribute Details
#create_time ⇒ Object
VM-Host Affinity policy creation time.
35 36 37 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 35 def create_time @create_time end |
#created_by ⇒ Object
Returns the value of attribute created_by.
40 41 42 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 40 def created_by @created_by end |
#description ⇒ Object
VM-Host Affinity policy description.
32 33 34 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 32 def description @description end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
23 24 25 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 23 def ext_id @ext_id end |
#host_categories ⇒ Object
Categories through which host is associated with the VM-host affinity policy.
48 49 50 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 48 def host_categories @host_categories end |
#last_updated_by ⇒ Object
Returns the value of attribute last_updated_by.
42 43 44 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 42 def last_updated_by @last_updated_by end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
26 27 28 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 26 def links @links end |
#name ⇒ Object
VM-Host Affinity policy name.
29 30 31 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 29 def name @name end |
#num_compliant_vms ⇒ Object
Number of VMs which are compliant with the VM-host affinity policy.
57 58 59 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 57 def num_compliant_vms @num_compliant_vms end |
#num_hosts ⇒ Object
Number of hosts associated with the VM-host affinity policy.
54 55 56 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 54 def num_hosts @num_hosts end |
#num_non_compliant_vms ⇒ Object
Number of VMs which are not compliant with the VM-host affinity policy.
60 61 62 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 60 def num_non_compliant_vms @num_non_compliant_vms end |
#num_vms ⇒ Object
Number of VMs associated with the VM-host affinity policy.
51 52 53 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 51 def num_vms @num_vms end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 20 def tenant_id @tenant_id end |
#update_time ⇒ Object
VM-Host Affinity policy last updated time.
38 39 40 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 38 def update_time @update_time end |
#vm_categories ⇒ Object
Categories through which VM is associated with the VM-host affinity policy.
45 46 47 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 45 def vm_categories @vm_categories end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
84 85 86 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 84 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 89 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 63 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'name' => :'name', :'description' => :'description', :'create_time' => :'createTime', :'update_time' => :'updateTime', :'created_by' => :'createdBy', :'last_updated_by' => :'lastUpdatedBy', :'vm_categories' => :'vmCategories', :'host_categories' => :'hostCategories', :'num_vms' => :'numVms', :'num_hosts' => :'numHosts', :'num_compliant_vms' => :'numCompliantVms', :'num_non_compliant_vms' => :'numNonCompliantVms' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 404 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
122 123 124 125 126 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 122 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 119 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 115 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 94 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'name' => :'String', :'description' => :'String', :'create_time' => :'Time', :'update_time' => :'Time', :'created_by' => :'VmmV40AhvPoliciesUserReference', :'last_updated_by' => :'VmmV40AhvPoliciesUserReference', :'vm_categories' => :'Array<VmmV40AhvPoliciesCategoryReference>', :'host_categories' => :'Array<VmmV40AhvPoliciesCategoryReference>', :'num_vms' => :'Integer', :'num_hosts' => :'Integer', :'num_compliant_vms' => :'Integer', :'num_non_compliant_vms' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 369 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && name == o.name && description == o.description && create_time == o.create_time && update_time == o.update_time && created_by == o.created_by && last_updated_by == o.last_updated_by && vm_categories == o.vm_categories && host_categories == o.host_categories && num_vms == o.num_vms && num_hosts == o.num_hosts && num_compliant_vms == o.num_compliant_vms && num_non_compliant_vms == o.num_non_compliant_vms end |
#eql?(o) ⇒ Boolean
391 392 393 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 391 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
397 398 399 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 397 def hash [tenant_id, ext_id, links, name, description, create_time, update_time, created_by, last_updated_by, vm_categories, host_categories, num_vms, num_hosts, num_compliant_vms, num_non_compliant_vms].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 213 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if !@name.nil? && @name.to_s.length > 80 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 80.') end if !@vm_categories.nil? && @vm_categories.length > 50 invalid_properties.push('invalid value for "vm_categories", number of items must be less than or equal to 50.') end if !@vm_categories.nil? && @vm_categories.length < 1 invalid_properties.push('invalid value for "vm_categories", number of items must be greater than or equal to 1.') end if !@host_categories.nil? && @host_categories.length > 50 invalid_properties.push('invalid value for "host_categories", number of items must be less than or equal to 50.') end if !@host_categories.nil? && @host_categories.length < 1 invalid_properties.push('invalid value for "host_categories", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 426 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_policies_vm_host_affinity_policy.rb', line 259 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@name.nil? && @name.to_s.length > 80 return false if !@vm_categories.nil? && @vm_categories.length > 50 return false if !@vm_categories.nil? && @vm_categories.length < 1 return false if !@host_categories.nil? && @host_categories.length > 50 return false if !@host_categories.nil? && @host_categories.length < 1 true end |