Class: NutanixVmm::VmmV40AhvStatsVmDiskStatsTuple
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40AhvStatsVmDiskStatsTuple
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb
Overview
A collection of VM disk stats.
Instance Attribute Summary collapse
-
#controller_avg_io_latency_micros ⇒ Object
The VM disk controller average I/O latency in microseconds.
-
#controller_avg_read_io_latency_micros ⇒ Object
The VM disk controller average read I/O latency in microseconds.
-
#controller_avg_read_io_size_kb ⇒ Object
The VM disk controller average read I/O size in kilobytes.
-
#controller_avg_write_io_latency_micros ⇒ Object
The VM disk controller average write I/O latency in microseconds.
-
#controller_avg_write_io_size_kb ⇒ Object
The VM disk controller average write I/O size in kilobytes.
-
#controller_frontend_read_ops ⇒ Object
The VM disk controller number of frontend read operations.
-
#controller_frontend_write_ops ⇒ Object
The VM disk controller number of frontend write operations.
-
#controller_io_bandwidth_kbps ⇒ Object
The VM disk controller number of I/O bandwidth in kilobytes per second.
-
#controller_num_io ⇒ Object
The VM disk controller number of I/O.
-
#controller_num_iops ⇒ Object
The VM disk controller number of I/O operations per second.
-
#controller_num_read_io ⇒ Object
The VM disk controller number of read I/O.
-
#controller_num_read_iops ⇒ Object
The VM disk controller number of read I/O operations per second.
-
#controller_num_write_io ⇒ Object
The VM disk controller number of write I/O.
-
#controller_random_read_ops ⇒ Object
The VM disk controller number of random read operations.
-
#controller_random_write_ops ⇒ Object
The VM disk controller number of random write operations.
-
#controller_read_io_bandwidth_kbps ⇒ Object
The VM disk controller number of read I/O bandwidth in kilobytes per second.
-
#controller_read_io_ppm ⇒ Object
The VM disk controller percentage of read I/O in parts per million.
-
#controller_seq_io_ppm ⇒ Object
The VM disk controller percentage of sequential I/O in parts per million.
-
#controller_timespan_micros ⇒ Object
The VM disk controller timespan in microseconds.
-
#controller_total_io_size_kb ⇒ Object
The VM disk controller total I/O size in kilobytes.
-
#controller_total_io_time_micros ⇒ Object
The VM disk controller total I/O time in microseconds.
-
#controller_total_read_io_size_kb ⇒ Object
The VM disk controller total read I/O size in kilobytes.
-
#controller_total_read_io_time_micros ⇒ Object
The VM disk controller total read I/O time in microseconds.
-
#controller_user_bytes ⇒ Object
The VM disk controller user bytes.
-
#controller_vdisk_cpu_time_micros ⇒ Object
The VM disk controller vDisk CPU time in microseconds.
-
#controller_write_io_bandwidth_kbps ⇒ Object
The VM disk controller write I/O bandwidth in kilobytes per second.
-
#controller_write_io_ppm ⇒ Object
The VM disk controller percentage of write I/O in parts per million.
-
#timestamp ⇒ Object
The timestamp of a specific VM stats response data point.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40AhvStatsVmDiskStatsTuple
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40AhvStatsVmDiskStatsTuple
Initializes the object
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 189 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40AhvStatsVmDiskStatsTuple` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40AhvStatsVmDiskStatsTuple`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'controller_avg_io_latency_micros') self.controller_avg_io_latency_micros = attributes[:'controller_avg_io_latency_micros'] end if attributes.key?(:'controller_avg_read_io_latency_micros') self.controller_avg_read_io_latency_micros = attributes[:'controller_avg_read_io_latency_micros'] end if attributes.key?(:'controller_avg_read_io_size_kb') self.controller_avg_read_io_size_kb = attributes[:'controller_avg_read_io_size_kb'] end if attributes.key?(:'controller_num_read_iops') self.controller_num_read_iops = attributes[:'controller_num_read_iops'] end if attributes.key?(:'controller_read_io_ppm') self.controller_read_io_ppm = attributes[:'controller_read_io_ppm'] end if attributes.key?(:'controller_num_write_io') self.controller_num_write_io = attributes[:'controller_num_write_io'] end if attributes.key?(:'controller_avg_write_io_latency_micros') self.controller_avg_write_io_latency_micros = attributes[:'controller_avg_write_io_latency_micros'] end if attributes.key?(:'controller_avg_write_io_size_kb') self.controller_avg_write_io_size_kb = attributes[:'controller_avg_write_io_size_kb'] end if attributes.key?(:'controller_io_bandwidth_kbps') self.controller_io_bandwidth_kbps = attributes[:'controller_io_bandwidth_kbps'] end if attributes.key?(:'controller_frontend_read_ops') self.controller_frontend_read_ops = attributes[:'controller_frontend_read_ops'] end if attributes.key?(:'controller_frontend_write_ops') self.controller_frontend_write_ops = attributes[:'controller_frontend_write_ops'] end if attributes.key?(:'controller_num_io') self.controller_num_io = attributes[:'controller_num_io'] end if attributes.key?(:'controller_num_iops') self.controller_num_iops = attributes[:'controller_num_iops'] end if attributes.key?(:'controller_num_read_io') self.controller_num_read_io = attributes[:'controller_num_read_io'] end if attributes.key?(:'controller_random_read_ops') self.controller_random_read_ops = attributes[:'controller_random_read_ops'] end if attributes.key?(:'controller_random_write_ops') self.controller_random_write_ops = attributes[:'controller_random_write_ops'] end if attributes.key?(:'controller_read_io_bandwidth_kbps') self.controller_read_io_bandwidth_kbps = attributes[:'controller_read_io_bandwidth_kbps'] end if attributes.key?(:'controller_seq_io_ppm') self.controller_seq_io_ppm = attributes[:'controller_seq_io_ppm'] end if attributes.key?(:'controller_timespan_micros') self.controller_timespan_micros = attributes[:'controller_timespan_micros'] end if attributes.key?(:'controller_total_io_size_kb') self.controller_total_io_size_kb = attributes[:'controller_total_io_size_kb'] end if attributes.key?(:'controller_total_io_time_micros') self.controller_total_io_time_micros = attributes[:'controller_total_io_time_micros'] end if attributes.key?(:'controller_total_read_io_size_kb') self.controller_total_read_io_size_kb = attributes[:'controller_total_read_io_size_kb'] end if attributes.key?(:'controller_total_read_io_time_micros') self.controller_total_read_io_time_micros = attributes[:'controller_total_read_io_time_micros'] end if attributes.key?(:'controller_user_bytes') self.controller_user_bytes = attributes[:'controller_user_bytes'] end if attributes.key?(:'controller_vdisk_cpu_time_micros') self.controller_vdisk_cpu_time_micros = attributes[:'controller_vdisk_cpu_time_micros'] end if attributes.key?(:'controller_write_io_bandwidth_kbps') self.controller_write_io_bandwidth_kbps = attributes[:'controller_write_io_bandwidth_kbps'] end if attributes.key?(:'controller_write_io_ppm') self.controller_write_io_ppm = attributes[:'controller_write_io_ppm'] end end |
Instance Attribute Details
#controller_avg_io_latency_micros ⇒ Object
The VM disk controller average I/O latency in microseconds.
23 24 25 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 23 def controller_avg_io_latency_micros @controller_avg_io_latency_micros end |
#controller_avg_read_io_latency_micros ⇒ Object
The VM disk controller average read I/O latency in microseconds.
26 27 28 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 26 def controller_avg_read_io_latency_micros @controller_avg_read_io_latency_micros end |
#controller_avg_read_io_size_kb ⇒ Object
The VM disk controller average read I/O size in kilobytes.
29 30 31 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 29 def controller_avg_read_io_size_kb @controller_avg_read_io_size_kb end |
#controller_avg_write_io_latency_micros ⇒ Object
The VM disk controller average write I/O latency in microseconds.
41 42 43 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 41 def controller_avg_write_io_latency_micros @controller_avg_write_io_latency_micros end |
#controller_avg_write_io_size_kb ⇒ Object
The VM disk controller average write I/O size in kilobytes.
44 45 46 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 44 def controller_avg_write_io_size_kb @controller_avg_write_io_size_kb end |
#controller_frontend_read_ops ⇒ Object
The VM disk controller number of frontend read operations.
50 51 52 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 50 def controller_frontend_read_ops @controller_frontend_read_ops end |
#controller_frontend_write_ops ⇒ Object
The VM disk controller number of frontend write operations.
53 54 55 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 53 def controller_frontend_write_ops @controller_frontend_write_ops end |
#controller_io_bandwidth_kbps ⇒ Object
The VM disk controller number of I/O bandwidth in kilobytes per second.
47 48 49 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 47 def controller_io_bandwidth_kbps @controller_io_bandwidth_kbps end |
#controller_num_io ⇒ Object
The VM disk controller number of I/O.
56 57 58 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 56 def controller_num_io @controller_num_io end |
#controller_num_iops ⇒ Object
The VM disk controller number of I/O operations per second.
59 60 61 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 59 def controller_num_iops @controller_num_iops end |
#controller_num_read_io ⇒ Object
The VM disk controller number of read I/O.
62 63 64 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 62 def controller_num_read_io @controller_num_read_io end |
#controller_num_read_iops ⇒ Object
The VM disk controller number of read I/O operations per second.
32 33 34 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 32 def controller_num_read_iops @controller_num_read_iops end |
#controller_num_write_io ⇒ Object
The VM disk controller number of write I/O.
38 39 40 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 38 def controller_num_write_io @controller_num_write_io end |
#controller_random_read_ops ⇒ Object
The VM disk controller number of random read operations.
65 66 67 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 65 def controller_random_read_ops @controller_random_read_ops end |
#controller_random_write_ops ⇒ Object
The VM disk controller number of random write operations.
68 69 70 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 68 def controller_random_write_ops @controller_random_write_ops end |
#controller_read_io_bandwidth_kbps ⇒ Object
The VM disk controller number of read I/O bandwidth in kilobytes per second.
71 72 73 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 71 def controller_read_io_bandwidth_kbps @controller_read_io_bandwidth_kbps end |
#controller_read_io_ppm ⇒ Object
The VM disk controller percentage of read I/O in parts per million.
35 36 37 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 35 def controller_read_io_ppm @controller_read_io_ppm end |
#controller_seq_io_ppm ⇒ Object
The VM disk controller percentage of sequential I/O in parts per million.
74 75 76 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 74 def controller_seq_io_ppm @controller_seq_io_ppm end |
#controller_timespan_micros ⇒ Object
The VM disk controller timespan in microseconds.
77 78 79 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 77 def controller_timespan_micros @controller_timespan_micros end |
#controller_total_io_size_kb ⇒ Object
The VM disk controller total I/O size in kilobytes.
80 81 82 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 80 def controller_total_io_size_kb @controller_total_io_size_kb end |
#controller_total_io_time_micros ⇒ Object
The VM disk controller total I/O time in microseconds.
83 84 85 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 83 def controller_total_io_time_micros @controller_total_io_time_micros end |
#controller_total_read_io_size_kb ⇒ Object
The VM disk controller total read I/O size in kilobytes.
86 87 88 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 86 def controller_total_read_io_size_kb @controller_total_read_io_size_kb end |
#controller_total_read_io_time_micros ⇒ Object
The VM disk controller total read I/O time in microseconds.
89 90 91 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 89 def controller_total_read_io_time_micros @controller_total_read_io_time_micros end |
#controller_user_bytes ⇒ Object
The VM disk controller user bytes.
92 93 94 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 92 def controller_user_bytes @controller_user_bytes end |
#controller_vdisk_cpu_time_micros ⇒ Object
The VM disk controller vDisk CPU time in microseconds.
95 96 97 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 95 def controller_vdisk_cpu_time_micros @controller_vdisk_cpu_time_micros end |
#controller_write_io_bandwidth_kbps ⇒ Object
The VM disk controller write I/O bandwidth in kilobytes per second.
98 99 100 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 98 def controller_write_io_bandwidth_kbps @controller_write_io_bandwidth_kbps end |
#controller_write_io_ppm ⇒ Object
The VM disk controller percentage of write I/O in parts per million.
101 102 103 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 101 def controller_write_io_ppm @controller_write_io_ppm end |
#timestamp ⇒ Object
The timestamp of a specific VM stats response data point.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 20 def @timestamp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
138 139 140 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 138 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
143 144 145 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 143 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 104 def self.attribute_map { :'timestamp' => :'timestamp', :'controller_avg_io_latency_micros' => :'controllerAvgIoLatencyMicros', :'controller_avg_read_io_latency_micros' => :'controllerAvgReadIoLatencyMicros', :'controller_avg_read_io_size_kb' => :'controllerAvgReadIoSizeKb', :'controller_num_read_iops' => :'controllerNumReadIops', :'controller_read_io_ppm' => :'controllerReadIoPpm', :'controller_num_write_io' => :'controllerNumWriteIo', :'controller_avg_write_io_latency_micros' => :'controllerAvgWriteIoLatencyMicros', :'controller_avg_write_io_size_kb' => :'controllerAvgWriteIoSizeKb', :'controller_io_bandwidth_kbps' => :'controllerIoBandwidthKbps', :'controller_frontend_read_ops' => :'controllerFrontendReadOps', :'controller_frontend_write_ops' => :'controllerFrontendWriteOps', :'controller_num_io' => :'controllerNumIo', :'controller_num_iops' => :'controllerNumIops', :'controller_num_read_io' => :'controllerNumReadIo', :'controller_random_read_ops' => :'controllerRandomReadOps', :'controller_random_write_ops' => :'controllerRandomWriteOps', :'controller_read_io_bandwidth_kbps' => :'controllerReadIoBandwidthKbps', :'controller_seq_io_ppm' => :'controllerSeqIoPpm', :'controller_timespan_micros' => :'controllerTimespanMicros', :'controller_total_io_size_kb' => :'controllerTotalIoSizeKb', :'controller_total_io_time_micros' => :'controllerTotalIoTimeMicros', :'controller_total_read_io_size_kb' => :'controllerTotalReadIoSizeKb', :'controller_total_read_io_time_micros' => :'controllerTotalReadIoTimeMicros', :'controller_user_bytes' => :'controllerUserBytes', :'controller_vdisk_cpu_time_micros' => :'controllerVdiskCpuTimeMicros', :'controller_write_io_bandwidth_kbps' => :'controllerWriteIoBandwidthKbps', :'controller_write_io_ppm' => :'controllerWriteIoPpm' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 381 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
182 183 184 185 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 182 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 148 def self.openapi_types { :'timestamp' => :'Time', :'controller_avg_io_latency_micros' => :'Integer', :'controller_avg_read_io_latency_micros' => :'Integer', :'controller_avg_read_io_size_kb' => :'Integer', :'controller_num_read_iops' => :'Integer', :'controller_read_io_ppm' => :'Integer', :'controller_num_write_io' => :'Integer', :'controller_avg_write_io_latency_micros' => :'Integer', :'controller_avg_write_io_size_kb' => :'Integer', :'controller_io_bandwidth_kbps' => :'Integer', :'controller_frontend_read_ops' => :'Integer', :'controller_frontend_write_ops' => :'Integer', :'controller_num_io' => :'Integer', :'controller_num_iops' => :'Integer', :'controller_num_read_io' => :'Integer', :'controller_random_read_ops' => :'Integer', :'controller_random_write_ops' => :'Integer', :'controller_read_io_bandwidth_kbps' => :'Integer', :'controller_seq_io_ppm' => :'Integer', :'controller_timespan_micros' => :'Integer', :'controller_total_io_size_kb' => :'Integer', :'controller_total_io_time_micros' => :'Integer', :'controller_total_read_io_size_kb' => :'Integer', :'controller_total_read_io_time_micros' => :'Integer', :'controller_user_bytes' => :'Integer', :'controller_vdisk_cpu_time_micros' => :'Integer', :'controller_write_io_bandwidth_kbps' => :'Integer', :'controller_write_io_ppm' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 333 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && controller_avg_io_latency_micros == o.controller_avg_io_latency_micros && controller_avg_read_io_latency_micros == o.controller_avg_read_io_latency_micros && controller_avg_read_io_size_kb == o.controller_avg_read_io_size_kb && controller_num_read_iops == o.controller_num_read_iops && controller_read_io_ppm == o.controller_read_io_ppm && controller_num_write_io == o.controller_num_write_io && controller_avg_write_io_latency_micros == o.controller_avg_write_io_latency_micros && controller_avg_write_io_size_kb == o.controller_avg_write_io_size_kb && controller_io_bandwidth_kbps == o.controller_io_bandwidth_kbps && controller_frontend_read_ops == o.controller_frontend_read_ops && controller_frontend_write_ops == o.controller_frontend_write_ops && controller_num_io == o.controller_num_io && controller_num_iops == o.controller_num_iops && controller_num_read_io == o.controller_num_read_io && controller_random_read_ops == o.controller_random_read_ops && controller_random_write_ops == o.controller_random_write_ops && controller_read_io_bandwidth_kbps == o.controller_read_io_bandwidth_kbps && controller_seq_io_ppm == o.controller_seq_io_ppm && controller_timespan_micros == o.controller_timespan_micros && controller_total_io_size_kb == o.controller_total_io_size_kb && controller_total_io_time_micros == o.controller_total_io_time_micros && controller_total_read_io_size_kb == o.controller_total_read_io_size_kb && controller_total_read_io_time_micros == o.controller_total_read_io_time_micros && controller_user_bytes == o.controller_user_bytes && controller_vdisk_cpu_time_micros == o.controller_vdisk_cpu_time_micros && controller_write_io_bandwidth_kbps == o.controller_write_io_bandwidth_kbps && controller_write_io_ppm == o.controller_write_io_ppm end |
#eql?(o) ⇒ Boolean
368 369 370 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 368 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
374 375 376 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 374 def hash [, controller_avg_io_latency_micros, controller_avg_read_io_latency_micros, controller_avg_read_io_size_kb, controller_num_read_iops, controller_read_io_ppm, controller_num_write_io, controller_avg_write_io_latency_micros, controller_avg_write_io_size_kb, controller_io_bandwidth_kbps, controller_frontend_read_ops, controller_frontend_write_ops, controller_num_io, controller_num_iops, controller_num_read_io, controller_random_read_ops, controller_random_write_ops, controller_read_io_bandwidth_kbps, controller_seq_io_ppm, controller_timespan_micros, controller_total_io_size_kb, controller_total_io_time_micros, controller_total_read_io_size_kb, controller_total_read_io_time_micros, controller_user_bytes, controller_vdisk_cpu_time_micros, controller_write_io_bandwidth_kbps, controller_write_io_ppm].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
318 319 320 321 322 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 318 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 403 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
326 327 328 329 |
# File 'lib/nutanix_vmm/models/vmm_v40_ahv_stats_vm_disk_stats_tuple.rb', line 326 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |