Class: NutanixVmm::VmmV40ContentImagePlacementStatus
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40ContentImagePlacementStatus
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb
Overview
Status of an image placement policy.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#compliance_status ⇒ Object
Returns the value of attribute compliance_status.
-
#conflicting_policy_ext_ids ⇒ Object
List of image placement policy external identifiers that conflict with the current one.
-
#enforced_cluster_ext_ids ⇒ Object
List of cluster external identifiers for the enforced placement policy.
-
#enforcement_mode ⇒ Object
Returns the value of attribute enforcement_mode.
-
#placement_policy_ext_id ⇒ Object
The external identifier of image placement policy.
-
#policy_cluster_ext_ids ⇒ Object
List of cluster external identifiers of the image location for the enforced placement policy.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40ContentImagePlacementStatus
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40ContentImagePlacementStatus
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ContentImagePlacementStatus` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ContentImagePlacementStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'placement_policy_ext_id') self.placement_policy_ext_id = attributes[:'placement_policy_ext_id'] else self.placement_policy_ext_id = nil end if attributes.key?(:'compliance_status') self.compliance_status = attributes[:'compliance_status'] else self.compliance_status = nil end if attributes.key?(:'enforcement_mode') self.enforcement_mode = attributes[:'enforcement_mode'] else self.enforcement_mode = nil end if attributes.key?(:'policy_cluster_ext_ids') if (value = attributes[:'policy_cluster_ext_ids']).is_a?(Array) self.policy_cluster_ext_ids = value end end if attributes.key?(:'enforced_cluster_ext_ids') if (value = attributes[:'enforced_cluster_ext_ids']).is_a?(Array) self.enforced_cluster_ext_ids = value end end if attributes.key?(:'conflicting_policy_ext_ids') if (value = attributes[:'conflicting_policy_ext_ids']).is_a?(Array) self.conflicting_policy_ext_ids = value end end end |
Instance Attribute Details
#compliance_status ⇒ Object
Returns the value of attribute compliance_status.
22 23 24 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 22 def compliance_status @compliance_status end |
#conflicting_policy_ext_ids ⇒ Object
List of image placement policy external identifiers that conflict with the current one.
33 34 35 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 33 def conflicting_policy_ext_ids @conflicting_policy_ext_ids end |
#enforced_cluster_ext_ids ⇒ Object
List of cluster external identifiers for the enforced placement policy.
30 31 32 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 30 def enforced_cluster_ext_ids @enforced_cluster_ext_ids end |
#enforcement_mode ⇒ Object
Returns the value of attribute enforcement_mode.
24 25 26 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 24 def enforcement_mode @enforcement_mode end |
#placement_policy_ext_id ⇒ Object
The external identifier of image placement policy.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 20 def placement_policy_ext_id @placement_policy_ext_id end |
#policy_cluster_ext_ids ⇒ Object
List of cluster external identifiers of the image location for the enforced placement policy.
27 28 29 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 27 def policy_cluster_ext_ids @policy_cluster_ext_ids end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 58 def self.attribute_map { :'placement_policy_ext_id' => :'placementPolicyExtId', :'compliance_status' => :'complianceStatus', :'enforcement_mode' => :'enforcementMode', :'policy_cluster_ext_ids' => :'policyClusterExtIds', :'enforced_cluster_ext_ids' => :'enforcedClusterExtIds', :'conflicting_policy_ext_ids' => :'conflictingPolicyExtIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 333 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 80 def self.openapi_types { :'placement_policy_ext_id' => :'String', :'compliance_status' => :'VmmV40ContentComplianceStatus', :'enforcement_mode' => :'VmmV40ContentEnforcementMode', :'policy_cluster_ext_ids' => :'Array<String>', :'enforced_cluster_ext_ids' => :'Array<String>', :'conflicting_policy_ext_ids' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
307 308 309 310 311 312 313 314 315 316 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 307 def ==(o) return true if self.equal?(o) self.class == o.class && placement_policy_ext_id == o.placement_policy_ext_id && compliance_status == o.compliance_status && enforcement_mode == o.enforcement_mode && policy_cluster_ext_ids == o.policy_cluster_ext_ids && enforced_cluster_ext_ids == o.enforced_cluster_ext_ids && conflicting_policy_ext_ids == o.conflicting_policy_ext_ids end |
#eql?(o) ⇒ Boolean
320 321 322 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 320 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
326 327 328 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 326 def hash [placement_policy_ext_id, compliance_status, enforcement_mode, policy_cluster_ext_ids, enforced_cluster_ext_ids, conflicting_policy_ext_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @placement_policy_ext_id.nil? invalid_properties.push('invalid value for "placement_policy_ext_id", placement_policy_ext_id cannot be nil.') end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if @placement_policy_ext_id !~ pattern invalid_properties.push("invalid value for \"placement_policy_ext_id\", must conform to the pattern #{pattern}.") end if @compliance_status.nil? invalid_properties.push('invalid value for "compliance_status", compliance_status cannot be nil.') end if @enforcement_mode.nil? invalid_properties.push('invalid value for "enforcement_mode", enforcement_mode cannot be nil.') end if !@policy_cluster_ext_ids.nil? && @policy_cluster_ext_ids.length > 200 invalid_properties.push('invalid value for "policy_cluster_ext_ids", number of items must be less than or equal to 200.') end if !@policy_cluster_ext_ids.nil? && @policy_cluster_ext_ids.length < 0 invalid_properties.push('invalid value for "policy_cluster_ext_ids", number of items must be greater than or equal to 0.') end if !@enforced_cluster_ext_ids.nil? && @enforced_cluster_ext_ids.length > 200 invalid_properties.push('invalid value for "enforced_cluster_ext_ids", number of items must be less than or equal to 200.') end if !@enforced_cluster_ext_ids.nil? && @enforced_cluster_ext_ids.length < 0 invalid_properties.push('invalid value for "enforced_cluster_ext_ids", number of items must be greater than or equal to 0.') end if !@conflicting_policy_ext_ids.nil? && @conflicting_policy_ext_ids.length > 100 invalid_properties.push('invalid value for "conflicting_policy_ext_ids", number of items must be less than or equal to 100.') end if !@conflicting_policy_ext_ids.nil? && @conflicting_policy_ext_ids.length < 0 invalid_properties.push('invalid value for "conflicting_policy_ext_ids", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 355 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/nutanix_vmm/models/vmm_v40_content_image_placement_status.rb', line 201 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @placement_policy_ext_id.nil? return false if @placement_policy_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if @compliance_status.nil? return false if @enforcement_mode.nil? return false if !@policy_cluster_ext_ids.nil? && @policy_cluster_ext_ids.length > 200 return false if !@policy_cluster_ext_ids.nil? && @policy_cluster_ext_ids.length < 0 return false if !@enforced_cluster_ext_ids.nil? && @enforced_cluster_ext_ids.length > 200 return false if !@enforced_cluster_ext_ids.nil? && @enforced_cluster_ext_ids.length < 0 return false if !@conflicting_policy_ext_ids.nil? && @conflicting_policy_ext_ids.length > 100 return false if !@conflicting_policy_ext_ids.nil? && @conflicting_policy_ext_ids.length < 0 true end |