Class: NutanixVmm::VmmV40ErrorAppMessage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40ErrorAppMessage
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_error_app_message.rb
Overview
Message with associated severity describing status of the current operation.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#arguments_map ⇒ Object
The map of argument name to value.
-
#code ⇒ Object
The code associated with this message.This string is typically prefixed by the namespace the endpoint belongs to.
-
#error_group ⇒ Object
The error group associated with this message of severity ERROR.
-
#locale ⇒ Object
Locale for this message.
-
#message ⇒ Object
The message string.
-
#severity ⇒ Object
Returns the value of attribute severity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40ErrorAppMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40ErrorAppMessage
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ErrorAppMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ErrorAppMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'message') self. = attributes[:'message'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'locale') self.locale = attributes[:'locale'] else self.locale = 'en_US' end if attributes.key?(:'error_group') self.error_group = attributes[:'error_group'] end if attributes.key?(:'arguments_map') if (value = attributes[:'arguments_map']).is_a?(Hash) self.arguments_map = value end end end |
Instance Attribute Details
#arguments_map ⇒ Object
The map of argument name to value.
34 35 36 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 34 def arguments_map @arguments_map end |
#code ⇒ Object
The code associated with this message.This string is typically prefixed by the namespace the endpoint belongs to. For example: VMM-40000
25 26 27 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 25 def code @code end |
#error_group ⇒ Object
The error group associated with this message of severity ERROR.
31 32 33 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 31 def error_group @error_group end |
#locale ⇒ Object
Locale for this message. The default locale would be ‘en-US’.
28 29 30 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 28 def locale @locale end |
#message ⇒ Object
The message string.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 20 def @message end |
#severity ⇒ Object
Returns the value of attribute severity.
22 23 24 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 22 def severity @severity end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 59 def self.attribute_map { :'message' => :'message', :'severity' => :'severity', :'code' => :'code', :'locale' => :'locale', :'error_group' => :'errorGroup', :'arguments_map' => :'argumentsMap' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 81 def self.openapi_types { :'message' => :'String', :'severity' => :'CommonV10ConfigMessageSeverity', :'code' => :'String', :'locale' => :'String', :'error_group' => :'String', :'arguments_map' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && severity == o.severity && code == o.code && locale == o.locale && error_group == o.error_group && arguments_map == o.arguments_map end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 179 def hash [, severity, code, locale, error_group, arguments_map].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 |
# File 'lib/nutanix_vmm/models/vmm_v40_error_app_message.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |