Class: NutanixVmm::VmmV40EsxiStatsVmStatsTuple
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40EsxiStatsVmStatsTuple
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb
Overview
A collection of VM stats.
Instance Attribute Summary collapse
-
#check_score ⇒ Object
The VM NCC health check score.
-
#cluster ⇒ Object
The UUID of the cluster on which the VM resides.
-
#controller_avg_io_latency_micros ⇒ Object
The VM controller average I/O latency in microseconds.
-
#controller_avg_read_io_latency_micros ⇒ Object
The VM controller average read I/O latency in microseconds.
-
#controller_avg_read_io_size_kb ⇒ Object
The VM controller average read I/O size in kilobytes.
-
#controller_avg_write_io_latency_micros ⇒ Object
The VM controller average write I/O latency in microseconds.
-
#controller_avg_write_io_size_kb ⇒ Object
The VM controller average write I/O size in kilobytes.
-
#controller_io_bandwidth_kbps ⇒ Object
The VM controller I/O bandwidth in kilobytes per second.
-
#controller_num_io ⇒ Object
The VM controller number of I/O requests.
-
#controller_num_iops ⇒ Object
The VM controller number of I/O operations per second.
-
#controller_num_random_io ⇒ Object
The VM controller number of random I/O.
-
#controller_num_read_io ⇒ Object
The VM controller number of read I/O.
-
#controller_num_read_iops ⇒ Object
The VM controller number of read I/O operations per second.
-
#controller_num_seq_io ⇒ Object
The VM controller number of sequential I/Os.
-
#controller_num_write_io ⇒ Object
The VM controller number of write I/O.
-
#controller_num_write_iops ⇒ Object
The VM controller number of write I/O operations per second.
-
#controller_random_io_ppm ⇒ Object
The VM controller number of random I/O PPM.
-
#controller_read_io_bandwidth_kbps ⇒ Object
The VM controller number of read I/O bandwidth in kilobytes per second.
-
#controller_read_io_ppm ⇒ Object
The VM controller number of read I/O PPM.
-
#controller_seq_io_ppm ⇒ Object
The VM controller number of sequential I/O PPM.
-
#controller_storage_tier_ssd_usage_bytes ⇒ Object
The VM controller total usage on SSD tier for the VM.
-
#controller_timespan_micros ⇒ Object
The VM controller timespan in microseconds.
-
#controller_total_io_size_kb ⇒ Object
The VM controller number of total I/O size in kilobytes.
-
#controller_total_io_time_micros ⇒ Object
The VM controller number of total I/O time in microseconds.
-
#controller_total_read_io_size_kb ⇒ Object
The VM controller number of total read I/O size in kilobytes.
-
#controller_total_read_io_time_micros ⇒ Object
The VM controller number of total read I/O time in microseconds.
-
#controller_total_transformed_usage_bytes ⇒ Object
The VM controller number of total transformed usage in bytes.
-
#controller_user_bytes ⇒ Object
The VM controller user bytes.
-
#controller_write_io_bandwidth_kbps ⇒ Object
The VM controller write I/O bandwidth in kilobytes per second.
-
#controller_write_io_ppm ⇒ Object
The VM controller percentage of write I/O in parts per million.
-
#hypervisor_avg_io_latency_micros ⇒ Object
The average I/O latency of the VM in microseconds.
-
#hypervisor_cpu_ready_time_ppm ⇒ Object
Percentage of time that the VM was ready, but could not get scheduled to run.
-
#hypervisor_cpu_usage_ppm ⇒ Object
The CPU usage of the VM in parts per million.
-
#hypervisor_io_bandwidth_kbps ⇒ Object
The I/O bandwidth of the VM in kilobytes per second.
-
#hypervisor_memory_usage_ppm ⇒ Object
Consolidated guest memory usage in percentage.
-
#hypervisor_num_io ⇒ Object
The number of I/O by the VM.
-
#hypervisor_num_iops ⇒ Object
The number of I/O operations by the VM per second.
-
#hypervisor_num_read_io ⇒ Object
The number of read I/O operations by the VM.
-
#hypervisor_num_read_iops ⇒ Object
The number of read I/O operations by the VM per second.
-
#hypervisor_num_received_bytes ⇒ Object
The number of bytes received by the VM.
-
#hypervisor_num_transmitted_bytes ⇒ Object
The number of bytes transmitted by the VM.
-
#hypervisor_num_write_io ⇒ Object
The number of write I/O by the VM.
-
#hypervisor_num_write_iops ⇒ Object
The number of write I/O operations by the VM per second.
-
#hypervisor_read_io_bandwidth_kbps ⇒ Object
The number of read I/O bandwidth of the VM in kilobytes per second.
-
#hypervisor_swap_in_rate_kbps ⇒ Object
The swap in rate of the VM in kilobytes per second.
-
#hypervisor_swap_out_rate_kbps ⇒ Object
The swap out rate of the VM in kilobytes per second.
-
#hypervisor_timespan_micros ⇒ Object
The timespan of the VM in microseconds.
-
#hypervisor_total_io_size_kb ⇒ Object
The total I/O size of the VM in kilobytes.
-
#hypervisor_total_io_time_micros ⇒ Object
The total I/O time of the VM in microseconds.
-
#hypervisor_total_read_io_size_kb ⇒ Object
The total read I/O size of the VM in kilobytes.
-
#hypervisor_type ⇒ Object
Hypervisor type of the VM.
-
#hypervisor_write_io_bandwidth_kbps ⇒ Object
The write I/O bandwidth of the VM in kilobytes per second.
-
#memory_usage_ppm ⇒ Object
The VM memory usage in PPM.
-
#timestamp ⇒ Object
The timestamp of a specific VM stats response data point.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40EsxiStatsVmStatsTuple
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40EsxiStatsVmStatsTuple
Initializes the object
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 319 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40EsxiStatsVmStatsTuple` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40EsxiStatsVmStatsTuple`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'check_score') self.check_score = attributes[:'check_score'] end if attributes.key?(:'cluster') self.cluster = attributes[:'cluster'] end if attributes.key?(:'controller_avg_io_latency_micros') self.controller_avg_io_latency_micros = attributes[:'controller_avg_io_latency_micros'] end if attributes.key?(:'controller_avg_read_io_latency_micros') self.controller_avg_read_io_latency_micros = attributes[:'controller_avg_read_io_latency_micros'] end if attributes.key?(:'controller_avg_read_io_size_kb') self.controller_avg_read_io_size_kb = attributes[:'controller_avg_read_io_size_kb'] end if attributes.key?(:'controller_avg_write_io_latency_micros') self.controller_avg_write_io_latency_micros = attributes[:'controller_avg_write_io_latency_micros'] end if attributes.key?(:'controller_avg_write_io_size_kb') self.controller_avg_write_io_size_kb = attributes[:'controller_avg_write_io_size_kb'] end if attributes.key?(:'controller_io_bandwidth_kbps') self.controller_io_bandwidth_kbps = attributes[:'controller_io_bandwidth_kbps'] end if attributes.key?(:'controller_num_io') self.controller_num_io = attributes[:'controller_num_io'] end if attributes.key?(:'controller_num_iops') self.controller_num_iops = attributes[:'controller_num_iops'] end if attributes.key?(:'controller_num_random_io') self.controller_num_random_io = attributes[:'controller_num_random_io'] end if attributes.key?(:'controller_num_read_io') self.controller_num_read_io = attributes[:'controller_num_read_io'] end if attributes.key?(:'controller_num_read_iops') self.controller_num_read_iops = attributes[:'controller_num_read_iops'] end if attributes.key?(:'controller_num_seq_io') self.controller_num_seq_io = attributes[:'controller_num_seq_io'] end if attributes.key?(:'controller_num_write_io') self.controller_num_write_io = attributes[:'controller_num_write_io'] end if attributes.key?(:'controller_num_write_iops') self.controller_num_write_iops = attributes[:'controller_num_write_iops'] end if attributes.key?(:'controller_random_io_ppm') self.controller_random_io_ppm = attributes[:'controller_random_io_ppm'] end if attributes.key?(:'controller_read_io_bandwidth_kbps') self.controller_read_io_bandwidth_kbps = attributes[:'controller_read_io_bandwidth_kbps'] end if attributes.key?(:'controller_read_io_ppm') self.controller_read_io_ppm = attributes[:'controller_read_io_ppm'] end if attributes.key?(:'controller_seq_io_ppm') self.controller_seq_io_ppm = attributes[:'controller_seq_io_ppm'] end if attributes.key?(:'controller_storage_tier_ssd_usage_bytes') self.controller_storage_tier_ssd_usage_bytes = attributes[:'controller_storage_tier_ssd_usage_bytes'] end if attributes.key?(:'controller_timespan_micros') self.controller_timespan_micros = attributes[:'controller_timespan_micros'] end if attributes.key?(:'controller_total_io_size_kb') self.controller_total_io_size_kb = attributes[:'controller_total_io_size_kb'] end if attributes.key?(:'controller_total_io_time_micros') self.controller_total_io_time_micros = attributes[:'controller_total_io_time_micros'] end if attributes.key?(:'controller_total_read_io_size_kb') self.controller_total_read_io_size_kb = attributes[:'controller_total_read_io_size_kb'] end if attributes.key?(:'controller_total_read_io_time_micros') self.controller_total_read_io_time_micros = attributes[:'controller_total_read_io_time_micros'] end if attributes.key?(:'controller_total_transformed_usage_bytes') self.controller_total_transformed_usage_bytes = attributes[:'controller_total_transformed_usage_bytes'] end if attributes.key?(:'controller_user_bytes') self.controller_user_bytes = attributes[:'controller_user_bytes'] end if attributes.key?(:'controller_write_io_bandwidth_kbps') self.controller_write_io_bandwidth_kbps = attributes[:'controller_write_io_bandwidth_kbps'] end if attributes.key?(:'controller_write_io_ppm') self.controller_write_io_ppm = attributes[:'controller_write_io_ppm'] end if attributes.key?(:'hypervisor_avg_io_latency_micros') self.hypervisor_avg_io_latency_micros = attributes[:'hypervisor_avg_io_latency_micros'] end if attributes.key?(:'hypervisor_cpu_ready_time_ppm') self.hypervisor_cpu_ready_time_ppm = attributes[:'hypervisor_cpu_ready_time_ppm'] end if attributes.key?(:'hypervisor_cpu_usage_ppm') self.hypervisor_cpu_usage_ppm = attributes[:'hypervisor_cpu_usage_ppm'] end if attributes.key?(:'hypervisor_io_bandwidth_kbps') self.hypervisor_io_bandwidth_kbps = attributes[:'hypervisor_io_bandwidth_kbps'] end if attributes.key?(:'hypervisor_memory_usage_ppm') self.hypervisor_memory_usage_ppm = attributes[:'hypervisor_memory_usage_ppm'] end if attributes.key?(:'hypervisor_num_io') self.hypervisor_num_io = attributes[:'hypervisor_num_io'] end if attributes.key?(:'hypervisor_num_iops') self.hypervisor_num_iops = attributes[:'hypervisor_num_iops'] end if attributes.key?(:'hypervisor_num_read_io') self.hypervisor_num_read_io = attributes[:'hypervisor_num_read_io'] end if attributes.key?(:'hypervisor_num_read_iops') self.hypervisor_num_read_iops = attributes[:'hypervisor_num_read_iops'] end if attributes.key?(:'hypervisor_num_received_bytes') self.hypervisor_num_received_bytes = attributes[:'hypervisor_num_received_bytes'] end if attributes.key?(:'hypervisor_num_transmitted_bytes') self.hypervisor_num_transmitted_bytes = attributes[:'hypervisor_num_transmitted_bytes'] end if attributes.key?(:'hypervisor_num_write_io') self.hypervisor_num_write_io = attributes[:'hypervisor_num_write_io'] end if attributes.key?(:'hypervisor_num_write_iops') self.hypervisor_num_write_iops = attributes[:'hypervisor_num_write_iops'] end if attributes.key?(:'hypervisor_read_io_bandwidth_kbps') self.hypervisor_read_io_bandwidth_kbps = attributes[:'hypervisor_read_io_bandwidth_kbps'] end if attributes.key?(:'hypervisor_swap_in_rate_kbps') self.hypervisor_swap_in_rate_kbps = attributes[:'hypervisor_swap_in_rate_kbps'] end if attributes.key?(:'hypervisor_swap_out_rate_kbps') self.hypervisor_swap_out_rate_kbps = attributes[:'hypervisor_swap_out_rate_kbps'] end if attributes.key?(:'hypervisor_timespan_micros') self.hypervisor_timespan_micros = attributes[:'hypervisor_timespan_micros'] end if attributes.key?(:'hypervisor_total_io_size_kb') self.hypervisor_total_io_size_kb = attributes[:'hypervisor_total_io_size_kb'] end if attributes.key?(:'hypervisor_total_io_time_micros') self.hypervisor_total_io_time_micros = attributes[:'hypervisor_total_io_time_micros'] end if attributes.key?(:'hypervisor_total_read_io_size_kb') self.hypervisor_total_read_io_size_kb = attributes[:'hypervisor_total_read_io_size_kb'] end if attributes.key?(:'hypervisor_write_io_bandwidth_kbps') self.hypervisor_write_io_bandwidth_kbps = attributes[:'hypervisor_write_io_bandwidth_kbps'] end if attributes.key?(:'hypervisor_type') self.hypervisor_type = attributes[:'hypervisor_type'] end if attributes.key?(:'memory_usage_ppm') self.memory_usage_ppm = attributes[:'memory_usage_ppm'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end end |
Instance Attribute Details
#check_score ⇒ Object
The VM NCC health check score.
20 21 22 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 20 def check_score @check_score end |
#cluster ⇒ Object
The UUID of the cluster on which the VM resides.
23 24 25 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 23 def cluster @cluster end |
#controller_avg_io_latency_micros ⇒ Object
The VM controller average I/O latency in microseconds.
26 27 28 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 26 def controller_avg_io_latency_micros @controller_avg_io_latency_micros end |
#controller_avg_read_io_latency_micros ⇒ Object
The VM controller average read I/O latency in microseconds.
29 30 31 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 29 def controller_avg_read_io_latency_micros @controller_avg_read_io_latency_micros end |
#controller_avg_read_io_size_kb ⇒ Object
The VM controller average read I/O size in kilobytes.
32 33 34 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 32 def controller_avg_read_io_size_kb @controller_avg_read_io_size_kb end |
#controller_avg_write_io_latency_micros ⇒ Object
The VM controller average write I/O latency in microseconds.
35 36 37 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 35 def controller_avg_write_io_latency_micros @controller_avg_write_io_latency_micros end |
#controller_avg_write_io_size_kb ⇒ Object
The VM controller average write I/O size in kilobytes.
38 39 40 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 38 def controller_avg_write_io_size_kb @controller_avg_write_io_size_kb end |
#controller_io_bandwidth_kbps ⇒ Object
The VM controller I/O bandwidth in kilobytes per second.
41 42 43 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 41 def controller_io_bandwidth_kbps @controller_io_bandwidth_kbps end |
#controller_num_io ⇒ Object
The VM controller number of I/O requests.
44 45 46 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 44 def controller_num_io @controller_num_io end |
#controller_num_iops ⇒ Object
The VM controller number of I/O operations per second.
47 48 49 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 47 def controller_num_iops @controller_num_iops end |
#controller_num_random_io ⇒ Object
The VM controller number of random I/O.
50 51 52 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 50 def controller_num_random_io @controller_num_random_io end |
#controller_num_read_io ⇒ Object
The VM controller number of read I/O.
53 54 55 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 53 def controller_num_read_io @controller_num_read_io end |
#controller_num_read_iops ⇒ Object
The VM controller number of read I/O operations per second.
56 57 58 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 56 def controller_num_read_iops @controller_num_read_iops end |
#controller_num_seq_io ⇒ Object
The VM controller number of sequential I/Os.
59 60 61 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 59 def controller_num_seq_io @controller_num_seq_io end |
#controller_num_write_io ⇒ Object
The VM controller number of write I/O.
62 63 64 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 62 def controller_num_write_io @controller_num_write_io end |
#controller_num_write_iops ⇒ Object
The VM controller number of write I/O operations per second.
65 66 67 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 65 def controller_num_write_iops @controller_num_write_iops end |
#controller_random_io_ppm ⇒ Object
The VM controller number of random I/O PPM.
68 69 70 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 68 def controller_random_io_ppm @controller_random_io_ppm end |
#controller_read_io_bandwidth_kbps ⇒ Object
The VM controller number of read I/O bandwidth in kilobytes per second.
71 72 73 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 71 def controller_read_io_bandwidth_kbps @controller_read_io_bandwidth_kbps end |
#controller_read_io_ppm ⇒ Object
The VM controller number of read I/O PPM.
74 75 76 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 74 def controller_read_io_ppm @controller_read_io_ppm end |
#controller_seq_io_ppm ⇒ Object
The VM controller number of sequential I/O PPM.
77 78 79 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 77 def controller_seq_io_ppm @controller_seq_io_ppm end |
#controller_storage_tier_ssd_usage_bytes ⇒ Object
The VM controller total usage on SSD tier for the VM.
80 81 82 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 80 def controller_storage_tier_ssd_usage_bytes @controller_storage_tier_ssd_usage_bytes end |
#controller_timespan_micros ⇒ Object
The VM controller timespan in microseconds.
83 84 85 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 83 def controller_timespan_micros @controller_timespan_micros end |
#controller_total_io_size_kb ⇒ Object
The VM controller number of total I/O size in kilobytes.
86 87 88 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 86 def controller_total_io_size_kb @controller_total_io_size_kb end |
#controller_total_io_time_micros ⇒ Object
The VM controller number of total I/O time in microseconds.
89 90 91 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 89 def controller_total_io_time_micros @controller_total_io_time_micros end |
#controller_total_read_io_size_kb ⇒ Object
The VM controller number of total read I/O size in kilobytes.
92 93 94 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 92 def controller_total_read_io_size_kb @controller_total_read_io_size_kb end |
#controller_total_read_io_time_micros ⇒ Object
The VM controller number of total read I/O time in microseconds.
95 96 97 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 95 def controller_total_read_io_time_micros @controller_total_read_io_time_micros end |
#controller_total_transformed_usage_bytes ⇒ Object
The VM controller number of total transformed usage in bytes.
98 99 100 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 98 def controller_total_transformed_usage_bytes @controller_total_transformed_usage_bytes end |
#controller_user_bytes ⇒ Object
The VM controller user bytes.
101 102 103 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 101 def controller_user_bytes @controller_user_bytes end |
#controller_write_io_bandwidth_kbps ⇒ Object
The VM controller write I/O bandwidth in kilobytes per second.
104 105 106 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 104 def controller_write_io_bandwidth_kbps @controller_write_io_bandwidth_kbps end |
#controller_write_io_ppm ⇒ Object
The VM controller percentage of write I/O in parts per million.
107 108 109 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 107 def controller_write_io_ppm @controller_write_io_ppm end |
#hypervisor_avg_io_latency_micros ⇒ Object
The average I/O latency of the VM in microseconds
110 111 112 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 110 def hypervisor_avg_io_latency_micros @hypervisor_avg_io_latency_micros end |
#hypervisor_cpu_ready_time_ppm ⇒ Object
Percentage of time that the VM was ready, but could not get scheduled to run.
113 114 115 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 113 def hypervisor_cpu_ready_time_ppm @hypervisor_cpu_ready_time_ppm end |
#hypervisor_cpu_usage_ppm ⇒ Object
The CPU usage of the VM in parts per million.
116 117 118 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 116 def hypervisor_cpu_usage_ppm @hypervisor_cpu_usage_ppm end |
#hypervisor_io_bandwidth_kbps ⇒ Object
The I/O bandwidth of the VM in kilobytes per second.
119 120 121 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 119 def hypervisor_io_bandwidth_kbps @hypervisor_io_bandwidth_kbps end |
#hypervisor_memory_usage_ppm ⇒ Object
Consolidated guest memory usage in percentage.
122 123 124 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 122 def hypervisor_memory_usage_ppm @hypervisor_memory_usage_ppm end |
#hypervisor_num_io ⇒ Object
The number of I/O by the VM.
125 126 127 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 125 def hypervisor_num_io @hypervisor_num_io end |
#hypervisor_num_iops ⇒ Object
The number of I/O operations by the VM per second.
128 129 130 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 128 def hypervisor_num_iops @hypervisor_num_iops end |
#hypervisor_num_read_io ⇒ Object
The number of read I/O operations by the VM.
131 132 133 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 131 def hypervisor_num_read_io @hypervisor_num_read_io end |
#hypervisor_num_read_iops ⇒ Object
The number of read I/O operations by the VM per second.
134 135 136 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 134 def hypervisor_num_read_iops @hypervisor_num_read_iops end |
#hypervisor_num_received_bytes ⇒ Object
The number of bytes received by the VM.
137 138 139 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 137 def hypervisor_num_received_bytes @hypervisor_num_received_bytes end |
#hypervisor_num_transmitted_bytes ⇒ Object
The number of bytes transmitted by the VM.
140 141 142 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 140 def hypervisor_num_transmitted_bytes @hypervisor_num_transmitted_bytes end |
#hypervisor_num_write_io ⇒ Object
The number of write I/O by the VM.
143 144 145 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 143 def hypervisor_num_write_io @hypervisor_num_write_io end |
#hypervisor_num_write_iops ⇒ Object
The number of write I/O operations by the VM per second.
146 147 148 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 146 def hypervisor_num_write_iops @hypervisor_num_write_iops end |
#hypervisor_read_io_bandwidth_kbps ⇒ Object
The number of read I/O bandwidth of the VM in kilobytes per second.
149 150 151 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 149 def hypervisor_read_io_bandwidth_kbps @hypervisor_read_io_bandwidth_kbps end |
#hypervisor_swap_in_rate_kbps ⇒ Object
The swap in rate of the VM in kilobytes per second.
152 153 154 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 152 def hypervisor_swap_in_rate_kbps @hypervisor_swap_in_rate_kbps end |
#hypervisor_swap_out_rate_kbps ⇒ Object
The swap out rate of the VM in kilobytes per second.
155 156 157 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 155 def hypervisor_swap_out_rate_kbps @hypervisor_swap_out_rate_kbps end |
#hypervisor_timespan_micros ⇒ Object
The timespan of the VM in microseconds.
158 159 160 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 158 def hypervisor_timespan_micros @hypervisor_timespan_micros end |
#hypervisor_total_io_size_kb ⇒ Object
The total I/O size of the VM in kilobytes.
161 162 163 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 161 def hypervisor_total_io_size_kb @hypervisor_total_io_size_kb end |
#hypervisor_total_io_time_micros ⇒ Object
The total I/O time of the VM in microseconds.
164 165 166 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 164 def hypervisor_total_io_time_micros @hypervisor_total_io_time_micros end |
#hypervisor_total_read_io_size_kb ⇒ Object
The total read I/O size of the VM in kilobytes.
167 168 169 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 167 def hypervisor_total_read_io_size_kb @hypervisor_total_read_io_size_kb end |
#hypervisor_type ⇒ Object
Hypervisor type of the VM.
173 174 175 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 173 def hypervisor_type @hypervisor_type end |
#hypervisor_write_io_bandwidth_kbps ⇒ Object
The write I/O bandwidth of the VM in kilobytes per second.
170 171 172 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 170 def hypervisor_write_io_bandwidth_kbps @hypervisor_write_io_bandwidth_kbps end |
#memory_usage_ppm ⇒ Object
The VM memory usage in PPM.
176 177 178 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 176 def memory_usage_ppm @memory_usage_ppm end |
#timestamp ⇒ Object
The timestamp of a specific VM stats response data point.
179 180 181 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 179 def @timestamp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
242 243 244 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 242 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
247 248 249 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 247 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 182 def self.attribute_map { :'check_score' => :'checkScore', :'cluster' => :'cluster', :'controller_avg_io_latency_micros' => :'controllerAvgIoLatencyMicros', :'controller_avg_read_io_latency_micros' => :'controllerAvgReadIoLatencyMicros', :'controller_avg_read_io_size_kb' => :'controllerAvgReadIoSizeKb', :'controller_avg_write_io_latency_micros' => :'controllerAvgWriteIoLatencyMicros', :'controller_avg_write_io_size_kb' => :'controllerAvgWriteIoSizeKb', :'controller_io_bandwidth_kbps' => :'controllerIoBandwidthKbps', :'controller_num_io' => :'controllerNumIo', :'controller_num_iops' => :'controllerNumIops', :'controller_num_random_io' => :'controllerNumRandomIo', :'controller_num_read_io' => :'controllerNumReadIo', :'controller_num_read_iops' => :'controllerNumReadIops', :'controller_num_seq_io' => :'controllerNumSeqIo', :'controller_num_write_io' => :'controllerNumWriteIo', :'controller_num_write_iops' => :'controllerNumWriteIops', :'controller_random_io_ppm' => :'controllerRandomIoPpm', :'controller_read_io_bandwidth_kbps' => :'controllerReadIoBandwidthKbps', :'controller_read_io_ppm' => :'controllerReadIoPpm', :'controller_seq_io_ppm' => :'controllerSeqIoPpm', :'controller_storage_tier_ssd_usage_bytes' => :'controllerStorageTierSsdUsageBytes', :'controller_timespan_micros' => :'controllerTimespanMicros', :'controller_total_io_size_kb' => :'controllerTotalIoSizeKb', :'controller_total_io_time_micros' => :'controllerTotalIoTimeMicros', :'controller_total_read_io_size_kb' => :'controllerTotalReadIoSizeKb', :'controller_total_read_io_time_micros' => :'controllerTotalReadIoTimeMicros', :'controller_total_transformed_usage_bytes' => :'controllerTotalTransformedUsageBytes', :'controller_user_bytes' => :'controllerUserBytes', :'controller_write_io_bandwidth_kbps' => :'controllerWriteIoBandwidthKbps', :'controller_write_io_ppm' => :'controllerWriteIoPpm', :'hypervisor_avg_io_latency_micros' => :'hypervisorAvgIoLatencyMicros', :'hypervisor_cpu_ready_time_ppm' => :'hypervisorCpuReadyTimePpm', :'hypervisor_cpu_usage_ppm' => :'hypervisorCpuUsagePpm', :'hypervisor_io_bandwidth_kbps' => :'hypervisorIoBandwidthKbps', :'hypervisor_memory_usage_ppm' => :'hypervisorMemoryUsagePpm', :'hypervisor_num_io' => :'hypervisorNumIo', :'hypervisor_num_iops' => :'hypervisorNumIops', :'hypervisor_num_read_io' => :'hypervisorNumReadIo', :'hypervisor_num_read_iops' => :'hypervisorNumReadIops', :'hypervisor_num_received_bytes' => :'hypervisorNumReceivedBytes', :'hypervisor_num_transmitted_bytes' => :'hypervisorNumTransmittedBytes', :'hypervisor_num_write_io' => :'hypervisorNumWriteIo', :'hypervisor_num_write_iops' => :'hypervisorNumWriteIops', :'hypervisor_read_io_bandwidth_kbps' => :'hypervisorReadIoBandwidthKbps', :'hypervisor_swap_in_rate_kbps' => :'hypervisorSwapInRateKbps', :'hypervisor_swap_out_rate_kbps' => :'hypervisorSwapOutRateKbps', :'hypervisor_timespan_micros' => :'hypervisorTimespanMicros', :'hypervisor_total_io_size_kb' => :'hypervisorTotalIoSizeKb', :'hypervisor_total_io_time_micros' => :'hypervisorTotalIoTimeMicros', :'hypervisor_total_read_io_size_kb' => :'hypervisorTotalReadIoSizeKb', :'hypervisor_write_io_bandwidth_kbps' => :'hypervisorWriteIoBandwidthKbps', :'hypervisor_type' => :'hypervisorType', :'memory_usage_ppm' => :'memoryUsagePpm', :'timestamp' => :'timestamp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 641 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
312 313 314 315 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 312 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 252 def self.openapi_types { :'check_score' => :'Integer', :'cluster' => :'String', :'controller_avg_io_latency_micros' => :'Integer', :'controller_avg_read_io_latency_micros' => :'Integer', :'controller_avg_read_io_size_kb' => :'Integer', :'controller_avg_write_io_latency_micros' => :'Integer', :'controller_avg_write_io_size_kb' => :'Integer', :'controller_io_bandwidth_kbps' => :'Integer', :'controller_num_io' => :'Integer', :'controller_num_iops' => :'Integer', :'controller_num_random_io' => :'Integer', :'controller_num_read_io' => :'Integer', :'controller_num_read_iops' => :'Integer', :'controller_num_seq_io' => :'Integer', :'controller_num_write_io' => :'Integer', :'controller_num_write_iops' => :'Integer', :'controller_random_io_ppm' => :'Integer', :'controller_read_io_bandwidth_kbps' => :'Integer', :'controller_read_io_ppm' => :'Integer', :'controller_seq_io_ppm' => :'Integer', :'controller_storage_tier_ssd_usage_bytes' => :'Integer', :'controller_timespan_micros' => :'Integer', :'controller_total_io_size_kb' => :'Integer', :'controller_total_io_time_micros' => :'Integer', :'controller_total_read_io_size_kb' => :'Integer', :'controller_total_read_io_time_micros' => :'Integer', :'controller_total_transformed_usage_bytes' => :'Integer', :'controller_user_bytes' => :'Integer', :'controller_write_io_bandwidth_kbps' => :'Integer', :'controller_write_io_ppm' => :'Integer', :'hypervisor_avg_io_latency_micros' => :'Integer', :'hypervisor_cpu_ready_time_ppm' => :'Integer', :'hypervisor_cpu_usage_ppm' => :'Integer', :'hypervisor_io_bandwidth_kbps' => :'Integer', :'hypervisor_memory_usage_ppm' => :'Integer', :'hypervisor_num_io' => :'Integer', :'hypervisor_num_iops' => :'Integer', :'hypervisor_num_read_io' => :'Integer', :'hypervisor_num_read_iops' => :'Integer', :'hypervisor_num_received_bytes' => :'Integer', :'hypervisor_num_transmitted_bytes' => :'Integer', :'hypervisor_num_write_io' => :'Integer', :'hypervisor_num_write_iops' => :'Integer', :'hypervisor_read_io_bandwidth_kbps' => :'Integer', :'hypervisor_swap_in_rate_kbps' => :'Integer', :'hypervisor_swap_out_rate_kbps' => :'Integer', :'hypervisor_timespan_micros' => :'Integer', :'hypervisor_total_io_size_kb' => :'Integer', :'hypervisor_total_io_time_micros' => :'Integer', :'hypervisor_total_read_io_size_kb' => :'Integer', :'hypervisor_write_io_bandwidth_kbps' => :'Integer', :'hypervisor_type' => :'String', :'memory_usage_ppm' => :'Integer', :'timestamp' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 567 def ==(o) return true if self.equal?(o) self.class == o.class && check_score == o.check_score && cluster == o.cluster && controller_avg_io_latency_micros == o.controller_avg_io_latency_micros && controller_avg_read_io_latency_micros == o.controller_avg_read_io_latency_micros && controller_avg_read_io_size_kb == o.controller_avg_read_io_size_kb && controller_avg_write_io_latency_micros == o.controller_avg_write_io_latency_micros && controller_avg_write_io_size_kb == o.controller_avg_write_io_size_kb && controller_io_bandwidth_kbps == o.controller_io_bandwidth_kbps && controller_num_io == o.controller_num_io && controller_num_iops == o.controller_num_iops && controller_num_random_io == o.controller_num_random_io && controller_num_read_io == o.controller_num_read_io && controller_num_read_iops == o.controller_num_read_iops && controller_num_seq_io == o.controller_num_seq_io && controller_num_write_io == o.controller_num_write_io && controller_num_write_iops == o.controller_num_write_iops && controller_random_io_ppm == o.controller_random_io_ppm && controller_read_io_bandwidth_kbps == o.controller_read_io_bandwidth_kbps && controller_read_io_ppm == o.controller_read_io_ppm && controller_seq_io_ppm == o.controller_seq_io_ppm && controller_storage_tier_ssd_usage_bytes == o.controller_storage_tier_ssd_usage_bytes && controller_timespan_micros == o.controller_timespan_micros && controller_total_io_size_kb == o.controller_total_io_size_kb && controller_total_io_time_micros == o.controller_total_io_time_micros && controller_total_read_io_size_kb == o.controller_total_read_io_size_kb && controller_total_read_io_time_micros == o.controller_total_read_io_time_micros && controller_total_transformed_usage_bytes == o.controller_total_transformed_usage_bytes && controller_user_bytes == o.controller_user_bytes && controller_write_io_bandwidth_kbps == o.controller_write_io_bandwidth_kbps && controller_write_io_ppm == o.controller_write_io_ppm && hypervisor_avg_io_latency_micros == o.hypervisor_avg_io_latency_micros && hypervisor_cpu_ready_time_ppm == o.hypervisor_cpu_ready_time_ppm && hypervisor_cpu_usage_ppm == o.hypervisor_cpu_usage_ppm && hypervisor_io_bandwidth_kbps == o.hypervisor_io_bandwidth_kbps && hypervisor_memory_usage_ppm == o.hypervisor_memory_usage_ppm && hypervisor_num_io == o.hypervisor_num_io && hypervisor_num_iops == o.hypervisor_num_iops && hypervisor_num_read_io == o.hypervisor_num_read_io && hypervisor_num_read_iops == o.hypervisor_num_read_iops && hypervisor_num_received_bytes == o.hypervisor_num_received_bytes && hypervisor_num_transmitted_bytes == o.hypervisor_num_transmitted_bytes && hypervisor_num_write_io == o.hypervisor_num_write_io && hypervisor_num_write_iops == o.hypervisor_num_write_iops && hypervisor_read_io_bandwidth_kbps == o.hypervisor_read_io_bandwidth_kbps && hypervisor_swap_in_rate_kbps == o.hypervisor_swap_in_rate_kbps && hypervisor_swap_out_rate_kbps == o.hypervisor_swap_out_rate_kbps && hypervisor_timespan_micros == o.hypervisor_timespan_micros && hypervisor_total_io_size_kb == o.hypervisor_total_io_size_kb && hypervisor_total_io_time_micros == o.hypervisor_total_io_time_micros && hypervisor_total_read_io_size_kb == o.hypervisor_total_read_io_size_kb && hypervisor_write_io_bandwidth_kbps == o.hypervisor_write_io_bandwidth_kbps && hypervisor_type == o.hypervisor_type && memory_usage_ppm == o.memory_usage_ppm && == o. end |
#eql?(o) ⇒ Boolean
628 629 630 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 628 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
634 635 636 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 634 def hash [check_score, cluster, controller_avg_io_latency_micros, controller_avg_read_io_latency_micros, controller_avg_read_io_size_kb, controller_avg_write_io_latency_micros, controller_avg_write_io_size_kb, controller_io_bandwidth_kbps, controller_num_io, controller_num_iops, controller_num_random_io, controller_num_read_io, controller_num_read_iops, controller_num_seq_io, controller_num_write_io, controller_num_write_iops, controller_random_io_ppm, controller_read_io_bandwidth_kbps, controller_read_io_ppm, controller_seq_io_ppm, controller_storage_tier_ssd_usage_bytes, controller_timespan_micros, controller_total_io_size_kb, controller_total_io_time_micros, controller_total_read_io_size_kb, controller_total_read_io_time_micros, controller_total_transformed_usage_bytes, controller_user_bytes, controller_write_io_bandwidth_kbps, controller_write_io_ppm, hypervisor_avg_io_latency_micros, hypervisor_cpu_ready_time_ppm, hypervisor_cpu_usage_ppm, hypervisor_io_bandwidth_kbps, hypervisor_memory_usage_ppm, hypervisor_num_io, hypervisor_num_iops, hypervisor_num_read_io, hypervisor_num_read_iops, hypervisor_num_received_bytes, hypervisor_num_transmitted_bytes, hypervisor_num_write_io, hypervisor_num_write_iops, hypervisor_read_io_bandwidth_kbps, hypervisor_swap_in_rate_kbps, hypervisor_swap_out_rate_kbps, hypervisor_timespan_micros, hypervisor_total_io_size_kb, hypervisor_total_io_time_micros, hypervisor_total_read_io_size_kb, hypervisor_write_io_bandwidth_kbps, hypervisor_type, memory_usage_ppm, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
552 553 554 555 556 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 552 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
663 664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 663 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
560 561 562 563 |
# File 'lib/nutanix_vmm/models/vmm_v40_esxi_stats_vm_stats_tuple.rb', line 560 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |