Class: NutanixVmm::VmmV40ImagesConfigRateLimitPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVmm::VmmV40ImagesConfigRateLimitPolicy
- Defined in:
- lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb
Instance Attribute Summary collapse
-
#cluster_entity_filter ⇒ Object
Returns the value of attribute cluster_entity_filter.
-
#create_time ⇒ Object
Image rate limit policy creation time.
-
#description ⇒ Object
Image rate limit policy specification.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#last_update_time ⇒ Object
Last updated time of an image rate limit policy.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#matching_cluster_ext_ids ⇒ Object
External identifier of the Prism Elements where a rate limit is the effective rate limit policy.
-
#name ⇒ Object
Name of the image rate limit policy.
-
#owner_ext_id ⇒ Object
External identifier of the owner of the rate limit policy.
-
#rate_limit_kbps ⇒ Object
Network bandwidth in KBps that the rate limited image operation can utilize.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VmmV40ImagesConfigRateLimitPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VmmV40ImagesConfigRateLimitPolicy
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVmm::VmmV40ImagesConfigRateLimitPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVmm::VmmV40ImagesConfigRateLimitPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'rate_limit_kbps') self.rate_limit_kbps = attributes[:'rate_limit_kbps'] else self.rate_limit_kbps = nil end if attributes.key?(:'cluster_entity_filter') self.cluster_entity_filter = attributes[:'cluster_entity_filter'] else self.cluster_entity_filter = nil end if attributes.key?(:'create_time') self.create_time = attributes[:'create_time'] end if attributes.key?(:'last_update_time') self.last_update_time = attributes[:'last_update_time'] end if attributes.key?(:'owner_ext_id') self.owner_ext_id = attributes[:'owner_ext_id'] end if attributes.key?(:'matching_cluster_ext_ids') if (value = attributes[:'matching_cluster_ext_ids']).is_a?(Array) self.matching_cluster_ext_ids = value end end end |
Instance Attribute Details
#cluster_entity_filter ⇒ Object
Returns the value of attribute cluster_entity_filter.
36 37 38 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 36 def cluster_entity_filter @cluster_entity_filter end |
#create_time ⇒ Object
Image rate limit policy creation time.
39 40 41 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 39 def create_time @create_time end |
#description ⇒ Object
Image rate limit policy specification.
31 32 33 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 31 def description @description end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
22 23 24 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 22 def ext_id @ext_id end |
#last_update_time ⇒ Object
Last updated time of an image rate limit policy.
42 43 44 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 42 def last_update_time @last_update_time end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
25 26 27 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 25 def links @links end |
#matching_cluster_ext_ids ⇒ Object
External identifier of the Prism Elements where a rate limit is the effective rate limit policy.
48 49 50 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 48 def matching_cluster_ext_ids @matching_cluster_ext_ids end |
#name ⇒ Object
Name of the image rate limit policy.
28 29 30 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 28 def name @name end |
#owner_ext_id ⇒ Object
External identifier of the owner of the rate limit policy.
45 46 47 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 45 def owner_ext_id @owner_ext_id end |
#rate_limit_kbps ⇒ Object
Network bandwidth in KBps that the rate limited image operation can utilize.
34 35 36 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 34 def rate_limit_kbps @rate_limit_kbps end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
19 20 21 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 19 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 51 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'name' => :'name', :'description' => :'description', :'rate_limit_kbps' => :'rateLimitKbps', :'cluster_entity_filter' => :'clusterEntityFilter', :'create_time' => :'createTime', :'last_update_time' => :'lastUpdateTime', :'owner_ext_id' => :'ownerExtId', :'matching_cluster_ext_ids' => :'matchingClusterExtIds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 442 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
102 103 104 105 106 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 102 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 99 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 95 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 78 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'name' => :'String', :'description' => :'String', :'rate_limit_kbps' => :'Integer', :'cluster_entity_filter' => :'VmmV40ImagesConfigFilter', :'create_time' => :'Time', :'last_update_time' => :'Time', :'owner_ext_id' => :'String', :'matching_cluster_ext_ids' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 411 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && name == o.name && description == o.description && rate_limit_kbps == o.rate_limit_kbps && cluster_entity_filter == o.cluster_entity_filter && create_time == o.create_time && last_update_time == o.last_update_time && owner_ext_id == o.owner_ext_id && matching_cluster_ext_ids == o.matching_cluster_ext_ids end |
#eql?(o) ⇒ Boolean
429 430 431 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 429 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
435 436 437 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 435 def hash [tenant_id, ext_id, links, name, description, rate_limit_kbps, cluster_entity_filter, create_time, last_update_time, owner_ext_id, matching_cluster_ext_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 181 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 256 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@description.nil? && @description.to_s.length > 1000 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.') end if @rate_limit_kbps.nil? invalid_properties.push('invalid value for "rate_limit_kbps", rate_limit_kbps cannot be nil.') end if @rate_limit_kbps > 4294967296 invalid_properties.push('invalid value for "rate_limit_kbps", must be smaller than or equal to 4294967296.') end if @rate_limit_kbps < 1 invalid_properties.push('invalid value for "rate_limit_kbps", must be greater than or equal to 1.') end if @cluster_entity_filter.nil? invalid_properties.push('invalid value for "cluster_entity_filter", cluster_entity_filter cannot be nil.') end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@owner_ext_id.nil? && @owner_ext_id !~ pattern invalid_properties.push("invalid value for \"owner_ext_id\", must conform to the pattern #{pattern}.") end if !@matching_cluster_ext_ids.nil? && @matching_cluster_ext_ids.length > 200 invalid_properties.push('invalid value for "matching_cluster_ext_ids", number of items must be less than or equal to 200.') end if !@matching_cluster_ext_ids.nil? && @matching_cluster_ext_ids.length < 0 invalid_properties.push('invalid value for "matching_cluster_ext_ids", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
464 465 466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 464 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/nutanix_vmm/models/vmm_v40_images_config_rate_limit_policy.rb', line 252 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if @name.nil? return false if @name.to_s.length > 256 return false if @name.to_s.length < 1 return false if !@description.nil? && @description.to_s.length > 1000 return false if @rate_limit_kbps.nil? return false if @rate_limit_kbps > 4294967296 return false if @rate_limit_kbps < 1 return false if @cluster_entity_filter.nil? return false if !@owner_ext_id.nil? && @owner_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@matching_cluster_ext_ids.nil? && @matching_cluster_ext_ids.length > 200 return false if !@matching_cluster_ext_ids.nil? && @matching_cluster_ext_ids.length < 0 true end |